
/****************************************************************************
** Form implementation generated from reading ui file './configure.ui'
**
** Created: Sun Jan 14 16:51:06 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "configure.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlistbox.h>
#include <qwidgetstack.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qframe.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qgroupbox.h>
#include <qcombobox.h>
#include <qspinbox.h>
#include <qtextedit.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

#include "./configure.ui.h"
static const unsigned char img0_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x0e,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x26, 0x2f, 0x9c, 0x8a, 0x00, 0x00, 0x00,
    0x86, 0x49, 0x44, 0x41, 0x54, 0x28, 0x91, 0xa5, 0x91, 0x4b, 0x0e, 0x84,
    0x20, 0x10, 0x05, 0xeb, 0x68, 0x7a, 0x34, 0x2e, 0xe6, 0x62, 0x12, 0xb8,
    0x56, 0xb9, 0x10, 0x07, 0xc5, 0xd6, 0xf8, 0xd9, 0xd0, 0x69, 0x08, 0x55,
    0x8f, 0x06, 0x15, 0x8b, 0xa8, 0xe4, 0x92, 0x79, 0xd4, 0x9b, 0xdb, 0xe6,
    0xe3, 0x6a, 0x16, 0xf9, 0x60, 0x16, 0x49, 0x7c, 0x30, 0x27, 0x64, 0xa8,
    0x09, 0x5e, 0x99, 0x07, 0x04, 0x3a, 0x72, 0xc2, 0xdb, 0x66, 0x50, 0x65,
    0x7f, 0xf8, 0x43, 0xa6, 0x06, 0x39, 0x33, 0x8f, 0xf5, 0xb2, 0x45, 0x80,
    0x4a, 0x4c, 0x34, 0xc8, 0x36, 0xc9, 0x89, 0x79, 0x3d, 0x5f, 0x96, 0x08,
    0x32, 0xe1, 0x95, 0x79, 0x85, 0xfc, 0x49, 0x63, 0x04, 0x09, 0x2e, 0xf7,
    0xb3, 0xd9, 0x37, 0x3d, 0xa4, 0x8b, 0x1d, 0xfd, 0xce, 0x91, 0xb8, 0x85,
    0x04, 0x6f, 0x0e, 0x13, 0xf4, 0x64, 0x58, 0x22, 0x5f, 0x99, 0x0f, 0x33,
    0x78, 0x5b, 0x67, 0x80, 0x95, 0x19, 0x7b, 0xbc, 0x37, 0x3d, 0xb3, 0x00,
    0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img1_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x01,
    0xed, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xc5, 0x93, 0x3d, 0x68, 0x53,
    0x51, 0x14, 0xc7, 0xff, 0xe7, 0xde, 0x9b, 0x21, 0x21, 0x81, 0x7c, 0x90,
    0x26, 0x2f, 0xe8, 0x60, 0x12, 0x10, 0x02, 0x2e, 0x1d, 0x14, 0xc7, 0xba,
    0xb9, 0x17, 0xdd, 0xa4, 0x20, 0x88, 0x59, 0x5c, 0x04, 0xa5, 0xd0, 0x41,
    0x70, 0x71, 0xd3, 0xdd, 0x41, 0x50, 0x5c, 0xea, 0xe4, 0xa4, 0x38, 0xd4,
    0x49, 0x07, 0x3b, 0x29, 0xd1, 0x64, 0x09, 0x49, 0xd4, 0x40, 0xf2, 0x1e,
    0x8f, 0xf8, 0xc8, 0xcd, 0xe7, 0xbb, 0xf7, 0x3c, 0x17, 0x53, 0xa4, 0xd2,
    0x52, 0xe8, 0xe0, 0x81, 0xc3, 0x99, 0x7e, 0xfc, 0x0f, 0xbf, 0xc3, 0xa1,
    0x28, 0x8a, 0x70, 0x9a, 0x12, 0xa7, 0xa2, 0x01, 0x50, 0xbd, 0x5e, 0x3f,
    0xcb, 0xcc, 0x3f, 0xc2, 0x30, 0x84, 0x31, 0x06, 0xd6, 0x5a, 0x30, 0x33,
    0x84, 0x10, 0x07, 0x4d, 0x44, 0x90, 0x52, 0x1e, 0x4c, 0x21, 0x44, 0x45,
    0x4a, 0x79, 0x93, 0x88, 0x2e, 0x08, 0x66, 0x7e, 0xcd, 0xcc, 0x57, 0x4f,
    0x18, 0x58, 0x02, 0xb0, 0x13, 0x45, 0xd1, 0x7b, 0x63, 0xcc, 0xa6, 0x31,
    0x66, 0x47, 0x00, 0x08, 0x63, 0xb1, 0xd8, 0x0b, 0x66, 0xde, 0x38, 0x8a,
    0x62, 0xe6, 0x1c, 0x80, 0xfb, 0xd9, 0x6c, 0x76, 0x2f, 0x9f, 0xcf, 0x3f,
    0x34, 0xc6, 0x7c, 0x37, 0xc6, 0x5c, 0x01, 0xf0, 0x59, 0x2c, 0x16, 0x8b,
    0xdd, 0x52, 0xa9, 0x94, 0x4b, 0xa7, 0xd3, 0xcf, 0xad, 0xb5, 0x97, 0x0f,
    0x81, 0x05, 0x66, 0xbe, 0x9d, 0x4a, 0xa5, 0x3e, 0xd4, 0x6a, 0xb5, 0x47,
    0xd9, 0x6c, 0xf6, 0xfc, 0x60, 0x30, 0x78, 0x63, 0xad, 0xbd, 0x46, 0x44,
    0x3f, 0x01, 0x40, 0x2d, 0x97, 0xcb, 0xfd, 0xc9, 0x64, 0xb2, 0x2c, 0x97,
    0xcb, 0x67, 0x26, 0x93, 0xc9, 0xcb, 0xf1, 0x78, 0xbc, 0x09, 0xe0, 0x9b,
    0xb5, 0x76, 0x2b, 0x99, 0x4c, 0x6e, 0x39, 0x8e, 0x73, 0xc9, 0x71, 0x1c,
    0xb8, 0xae, 0x8b, 0x76, 0xbb, 0xfd, 0x4a, 0x08, 0x71, 0x4b, 0x4a, 0xf9,
    0x6b, 0x15, 0xa2, 0x8c, 0x31, 0x2d, 0xcf, 0xf3, 0x1a, 0xc5, 0x62, 0x71,
    0xbd, 0x52, 0xa9, 0x9c, 0x6b, 0xb5, 0x5a, 0xbb, 0xd6, 0x5a, 0xdf, 0x71,
    0x9c, 0x8b, 0x85, 0x42, 0x01, 0xf1, 0x78, 0x1c, 0x9d, 0x4e, 0x07, 0xbd,
    0x5e, 0xef, 0x89, 0x52, 0xea, 0x81, 0x10, 0x22, 0xf8, 0x7b, 0x4b, 0x05,
    0xc0, 0x0d, 0x82, 0xe0, 0xd3, 0x68, 0x34, 0x5a, 0xcf, 0x64, 0x32, 0xa8,
    0x56, 0xab, 0x15, 0x22, 0xaa, 0x24, 0x12, 0x09, 0x30, 0x33, 0x1a, 0x8d,
    0x86, 0x71, 0x5d, 0xf7, 0xb1, 0x10, 0x62, 0x9b, 0x88, 0xec, 0x61, 0x3f,
    0xc2, 0x5a, 0x8b, 0x30, 0x0c, 0xf7, 0x7d, 0xdf, 0xb7, 0xb3, 0xd9, 0x0c,
    0x52, 0x4a, 0x28, 0xa5, 0xa0, 0xb5, 0x46, 0xb3, 0xd9, 0x44, 0xbf, 0xdf,
    0xdf, 0x8e, 0xa2, 0xe8, 0x9e, 0x10, 0xe2, 0x1f, 0x78, 0xe5, 0x00, 0x00,
    0x3e, 0xfa, 0xbe, 0xef, 0xe7, 0x72, 0xb9, 0x35, 0x29, 0x25, 0xe6, 0xf3,
    0x39, 0xba, 0xdd, 0xee, 0x3c, 0x08, 0x82, 0x3b, 0x4a, 0xa9, 0xa7, 0x44,
    0x74, 0xe4, 0x5d, 0xd5, 0x1f, 0xdb, 0x2d, 0xad, 0xf5, 0xd7, 0xe9, 0x74,
    0xba, 0xc6, 0xcc, 0xe8, 0xf5, 0x7a, 0x23, 0xad, 0xf5, 0x5d, 0xa5, 0xd4,
    0xb3, 0xe3, 0x60, 0x00, 0x50, 0xd6, 0x5a, 0x44, 0x51, 0x04, 0x22, 0xda,
    0x1b, 0x0e, 0x87, 0x1b, 0xd3, 0xe9, 0xd4, 0xd3, 0x5a, 0xdf, 0x20, 0xa2,
    0xb7, 0xc7, 0x92, 0x2b, 0x07, 0x00, 0x40, 0x44, 0x60, 0xe6, 0x77, 0x9e,
    0xe7, 0x7d, 0xd1, 0x5a, 0x5f, 0x3f, 0x29, 0x0c, 0x00, 0xf4, 0xdf, 0xbf,
    0xf1, 0x37, 0xfd, 0xb3, 0xf9, 0xdd, 0x92, 0x71, 0x44, 0x5d, 0x00, 0x00,
    0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img2_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x03,
    0x07, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0x6d, 0x93, 0x5b, 0x68, 0x1c,
    0x75, 0x18, 0xc5, 0x7f, 0xdf, 0x7f, 0x66, 0x67, 0x2f, 0xce, 0xee, 0x26,
    0xbb, 0xd9, 0x4b, 0x2e, 0xb2, 0x68, 0x52, 0x1a, 0x29, 0xc6, 0x6d, 0x6a,
    0x9a, 0xd2, 0xd4, 0x82, 0xa6, 0x2d, 0xa8, 0x08, 0xfa, 0x20, 0x48, 0x40,
    0x45, 0x30, 0x54, 0x10, 0xab, 0xe8, 0xab, 0x0f, 0x0a, 0x2a, 0x82, 0x14,
    0x15, 0x8b, 0x28, 0xa3, 0x15, 0x5f, 0x04, 0x8b, 0x3e, 0x68, 0x05, 0x6d,
    0x50, 0x5a, 0x4a, 0x4b, 0x2f, 0x69, 0x93, 0xd4, 0x16, 0x9b, 0x2c, 0x36,
    0xb2, 0x66, 0xa9, 0xb9, 0x6c, 0xd8, 0x4b, 0x36, 0x1b, 0x77, 0xb3, 0x33,
    0xe3, 0x43, 0x6c, 0x34, 0x6d, 0x3f, 0xf8, 0xde, 0xce, 0x39, 0x70, 0xbe,
    0x73, 0x3e, 0xe1, 0x36, 0x73, 0x69, 0x5b, 0xbf, 0xcf, 0x71, 0xdd, 0x3e,
    0x07, 0xba, 0x5c, 0x5c, 0x71, 0x91, 0x6b, 0x65, 0x5d, 0x1b, 0x1d, 0x3c,
    0x7f, 0xa6, 0x7a, 0x33, 0x56, 0x6e, 0x22, 0x9a, 0x02, 0xaf, 0x7b, 0x5c,
    0xf7, 0x85, 0xa0, 0x52, 0xe1, 0xc6, 0x9d, 0x1d, 0x34, 0x02, 0x01, 0x7c,
    0x99, 0x0c, 0x45, 0xdb, 0x29, 0x55, 0x85, 0xaf, 0x8b, 0xba, 0xe7, 0xed,
    0x7d, 0xe7, 0x4e, 0xff, 0x79, 0x8b, 0xc0, 0xa5, 0x6d, 0xfd, 0x49, 0x05,
    0x27, 0xa2, 0x89, 0xf8, 0xe6, 0xf0, 0x33, 0x4f, 0xa3, 0xed, 0x1a, 0x40,
    0x0b, 0x05, 0x01, 0x70, 0x6b, 0x75, 0xaa, 0x63, 0xe3, 0x54, 0xbe, 0xf8,
    0x92, 0xf9, 0xcc, 0x54, 0x7e, 0xd6, 0xef, 0x7f, 0xf2, 0x91, 0xd3, 0x27,
    0x4f, 0xac, 0x0b, 0x4c, 0xf4, 0x6e, 0x37, 0x95, 0xc8, 0x85, 0xb6, 0xde,
    0xad, 0x9b, 0x7d, 0xaf, 0x1c, 0x40, 0x0f, 0x9a, 0xb7, 0x73, 0x86, 0xb3,
    0xda, 0xa0, 0xf0, 0xf9, 0x61, 0xe6, 0x7e, 0x3a, 0xb6, 0x38, 0x69, 0x9a,
    0xf7, 0x0e, 0x9d, 0x3c, 0xfe, 0x97, 0x06, 0xb0, 0xbf, 0xb5, 0xfd, 0x9d,
    0x58, 0x32, 0xf9, 0x98, 0xff, 0xa5, 0x17, 0xd1, 0x43, 0x26, 0x9e, 0x96,
    0x16, 0xea, 0xb9, 0x1c, 0x4e, 0xb5, 0xba, 0xbe, 0x28, 0x85, 0x91, 0x88,
    0xa3, 0xc5, 0x63, 0x68, 0xbf, 0x4f, 0x07, 0x64, 0x76, 0x2e, 0xa8, 0x3d,
    0xfa, 0xf0, 0x88, 0xba, 0xd0, 0xdb, 0xe7, 0xf3, 0xc0, 0xf3, 0xde, 0x7d,
    0x7b, 0xb1, 0x2b, 0x15, 0xf4, 0x68, 0x14, 0x2d, 0x18, 0xc4, 0x48, 0xa5,
    0xa8, 0xcf, 0xe7, 0xa9, 0xcf, 0xe7, 0x71, 0x56, 0x6d, 0xfc, 0x9b, 0x36,
    0xa1, 0x05, 0x83, 0xb8, 0xb6, 0x83, 0x3c, 0xb0, 0x8b, 0x90, 0xe3, 0x0c,
    0x6d, 0x99, 0xc9, 0xb5, 0xe9, 0x40, 0x9f, 0x69, 0x18, 0x61, 0xbb, 0xb9,
    0x09, 0x27, 0x9f, 0xa7, 0xf8, 0xe3, 0x31, 0xc2, 0x7b, 0x1e, 0xc2, 0x48,
    0x24, 0xb8, 0x23, 0xdd, 0x43, 0xf5, 0xd7, 0x2b, 0x04, 0xb7, 0xdf, 0x0f,
    0xc0, 0xe2, 0x77, 0xdf, 0x63, 0x7e, 0xfa, 0x19, 0xed, 0xe5, 0x25, 0x5c,
    0xa5, 0xcc, 0xce, 0x72, 0x65, 0xa7, 0x0e, 0x74, 0xa9, 0x48, 0x84, 0x46,
    0x3e, 0x8f, 0x68, 0x1a, 0x28, 0xc5, 0xe2, 0x91, 0x6f, 0x88, 0x3c, 0xf1,
    0x38, 0xde, 0x8e, 0x76, 0x8c, 0xbd, 0x09, 0x00, 0x96, 0x0e, 0x7d, 0x4c,
    0xe0, 0x97, 0xe3, 0x78, 0x97, 0x96, 0x41, 0xc0, 0xa7, 0x69, 0x78, 0x44,
    0xba, 0x74, 0x40, 0xb4, 0x7a, 0x1d, 0x2d, 0x3b, 0x83, 0x18, 0x06, 0x62,
    0x18, 0xf8, 0xf2, 0x0b, 0x30, 0x37, 0x0f, 0x6f, 0xbd, 0xb9, 0x76, 0xbd,
    0xf1, 0x09, 0x82, 0x47, 0xbe, 0xfd, 0x2f, 0x37, 0x57, 0x01, 0x82, 0x23,
    0xa2, 0x94, 0x8b, 0x5c, 0x73, 0x4a, 0x25, 0xa2, 0x53, 0x19, 0x22, 0x97,
    0xaf, 0xd0, 0x7c, 0x71, 0x8c, 0x40, 0x28, 0x84, 0xf7, 0x7f, 0x64, 0xb6,
    0xa6, 0xe1, 0xc3, 0x83, 0xff, 0x0a, 0x08, 0xe8, 0x1a, 0x35, 0xa7, 0xc1,
    0x8a, 0x48, 0x4e, 0x95, 0x75, 0x6d, 0xb4, 0x64, 0xdb, 0x25, 0x11, 0x41,
    0x34, 0x85, 0xa4, 0x7b, 0xd0, 0xde, 0x7b, 0x77, 0x0d, 0x7c, 0xe0, 0x55,
    0x78, 0xf9, 0xb5, 0x75, 0x11, 0xf7, 0xa3, 0xf7, 0xb1, 0x03, 0x7e, 0x6c,
    0x9f, 0x8f, 0x82, 0xed, 0x2c, 0x5f, 0x8d, 0x34, 0x8d, 0xab, 0xc1, 0xf3,
    0x67, 0xaa, 0x55, 0xe1, 0xf0, 0xac, 0x12, 0xca, 0x1d, 0x1d, 0x38, 0xcf,
    0x3d, 0xbb, 0xe6, 0xf9, 0xe0, 0x07, 0x14, 0x6a, 0x35, 0x0a, 0xf7, 0x74,
    0x53, 0xf8, 0xc4, 0x62, 0x75, 0x2a, 0x83, 0xdc, 0xd7, 0x43, 0x75, 0xcf,
    0x20, 0xb3, 0x4a, 0x58, 0xf0, 0xe8, 0x47, 0xb3, 0xf1, 0xd8, 0x75, 0x01,
    0x18, 0xe9, 0x1f, 0x68, 0x8e, 0xd8, 0x8d, 0xd1, 0x96, 0x1d, 0x3b, 0x3a,
    0x8d, 0x96, 0xe8, 0x5a, 0x84, 0xd9, 0xec, 0x2d, 0x45, 0x32, 0x52, 0x29,
    0x2a, 0x17, 0xc7, 0x58, 0x38, 0x7b, 0x36, 0xf7, 0x73, 0x5b, 0xeb, 0x53,
    0xd3, 0x89, 0xd8, 0xe8, 0x7a, 0x95, 0x7f, 0x18, 0xd8, 0xdd, 0x99, 0xac,
    0xd7, 0x47, 0xc2, 0xe9, 0xf4, 0xdd, 0x66, 0x77, 0x37, 0x22, 0x1b, 0xc9,
    0xae, 0x0b, 0x95, 0xc9, 0x49, 0x8a, 0x13, 0x13, 0xb9, 0x53, 0xc9, 0xc4,
    0xfe, 0xdf, 0x92, 0xf1, 0x53, 0x96, 0x65, 0x95, 0x37, 0xc0, 0xbe, 0xda,
    0xfd, 0x60, 0x6b, 0xaa, 0xba, 0xf2, 0x46, 0x20, 0x10, 0x18, 0x32, 0xee,
    0x4a, 0x99, 0xde, 0xa6, 0x66, 0x00, 0x6a, 0xc5, 0x02, 0xf5, 0x3f, 0xb2,
    0xcb, 0x85, 0xda, 0xdf, 0x47, 0xcf, 0x25, 0xe2, 0x87, 0xa6, 0x13, 0xb1,
    0xcb, 0x96, 0x65, 0x95, 0x37, 0x3c, 0xd3, 0x8d, 0x19, 0x1e, 0x1e, 0x36,
    0xb6, 0xcc, 0xe4, 0xda, 0x3a, 0xcb, 0x95, 0x9d, 0x1e, 0x91, 0x2e, 0x47,
    0x44, 0xad, 0x88, 0xe4, 0xae, 0x46, 0x9a, 0xc6, 0xb3, 0xf1, 0xd8, 0x75,
    0x60, 0xd1, 0xb2, 0xac, 0xfa, 0x0d, 0xfc, 0x3f, 0xf6, 0x5f, 0x26, 0x12,
    0xa2, 0x88, 0xfa, 0x15, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44,
    0xae, 0x42, 0x60, 0x82
};

static const unsigned char img3_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x01,
    0x8e, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0x95, 0x93, 0x3f, 0x4b, 0x1c,
    0x51, 0x14, 0xc5, 0x7f, 0x77, 0x33, 0x96, 0xe2, 0x07, 0x90, 0x94, 0x62,
    0x67, 0xd4, 0xc2, 0xef, 0x20, 0x49, 0x13, 0x05, 0x0b, 0x0b, 0x21, 0x85,
    0x88, 0x85, 0xa8, 0x20, 0x82, 0xb0, 0x04, 0x02, 0x2a, 0x04, 0x44, 0x12,
    0x2c, 0x6c, 0xfc, 0x0a, 0x82, 0x5b, 0xd9, 0xa4, 0xb1, 0x14, 0x82, 0xa2,
    0xec, 0x6e, 0x63, 0x67, 0x48, 0x61, 0xa1, 0x2b, 0x2e, 0xb3, 0x6f, 0xfe,
    0xbd, 0xbd, 0x16, 0x6f, 0x66, 0x67, 0x75, 0xd8, 0x15, 0x0f, 0x0c, 0x97,
    0xfb, 0xee, 0xdc, 0x73, 0xcf, 0x3d, 0x33, 0x4f, 0x48, 0x31, 0xb9, 0x71,
    0xa3, 0x28, 0x08, 0xa0, 0x22, 0x80, 0x02, 0x70, 0xb1, 0x37, 0x22, 0xbc,
    0x85, 0x89, 0xb5, 0xba, 0xfa, 0xb1, 0x55, 0x3f, 0xb4, 0x79, 0x4c, 0x9f,
    0x89, 0xb5, 0xba, 0xf6, 0xeb, 0xf5, 0xc6, 0x57, 0xae, 0xf5, 0x74, 0x67,
    0x94, 0x66, 0x94, 0x9e, 0xa4, 0xc3, 0x33, 0x0d, 0x63, 0x83, 0x37, 0xb0,
    0x72, 0xa5, 0x2a, 0x20, 0x08, 0x8a, 0x76, 0xea, 0x97, 0x07, 0x9f, 0xc4,
    0xc3, 0x46, 0x34, 0xe3, 0x22, 0xb3, 0xb6, 0x41, 0x4a, 0x50, 0x5e, 0xff,
    0xe2, 0x72, 0x5c, 0x4e, 0x1b, 0x28, 0xb9, 0x7c, 0xce, 0xfe, 0x55, 0x4f,
    0x93, 0x88, 0xc7, 0xa0, 0x8f, 0x46, 0x81, 0xf9, 0xcd, 0x6a, 0x8f, 0xe2,
    0x00, 0x9e, 0xda, 0x88, 0x87, 0x54, 0xfe, 0x07, 0xc0, 0x66, 0x51, 0x5d,
    0x5c, 0xfe, 0x5e, 0x65, 0x6b, 0xe9, 0x23, 0x0b, 0x53, 0x43, 0x2f, 0x5a,
    0x4f, 0x6a, 0xb0, 0xb5, 0x5f, 0xc5, 0xd3, 0xb6, 0x75, 0x0a, 0x04, 0xca,
    0xdb, 0xc5, 0x49, 0xdf, 0xe6, 0x87, 0x59, 0x98, 0x1a, 0xe2, 0xd7, 0x19,
    0xd8, 0xec, 0x7b, 0x74, 0xd9, 0xea, 0xa9, 0x8d, 0x79, 0x0c, 0xe1, 0xe7,
    0xee, 0x05, 0xd3, 0x5f, 0x27, 0xf9, 0x3d, 0x53, 0x14, 0xba, 0x7a, 0x4c,
    0xee, 0x6a, 0x17, 0x6c, 0x14, 0xe3, 0x69, 0x12, 0xd2, 0x08, 0xc0, 0x86,
    0x11, 0xff, 0x1f, 0x60, 0xf6, 0x28, 0x9f, 0x22, 0x52, 0xe8, 0xc9, 0x79,
    0x14, 0x92, 0x30, 0x74, 0x2b, 0x3c, 0x85, 0x60, 0x4d, 0xc0, 0x5d, 0x23,
    0x7d, 0x23, 0x93, 0xd9, 0x3d, 0xb5, 0xfb, 0x77, 0x4a, 0x6b, 0xd6, 0x04,
    0xce, 0xc4, 0x66, 0x04, 0x89, 0x09, 0x68, 0xf8, 0x3d, 0x9a, 0x5f, 0x1d,
    0x65, 0x5c, 0xb6, 0x15, 0x38, 0x0f, 0xfc, 0x10, 0x62, 0xe3, 0x53, 0xfb,
    0x51, 0xdc, 0xbf, 0x17, 0x2a, 0x95, 0x73, 0x16, 0xff, 0x18, 0x4a, 0xb4,
    0x93, 0x0e, 0xdb, 0x7b, 0x61, 0x5b, 0x2d, 0x3c, 0xb5, 0x09, 0xf7, 0x06,
    0xe2, 0xc0, 0x50, 0xa9, 0x9c, 0xbf, 0x8b, 0x20, 0x09, 0x8c, 0x5b, 0x67,
    0xf4, 0xf3, 0xa1, 0xde, 0x5e, 0x47, 0x79, 0x45, 0xe0, 0xc5, 0xd6, 0x2a,
    0x20, 0xaf, 0xdc, 0x54, 0x30, 0xff, 0x56, 0x45, 0x54, 0xfb, 0x5e, 0xb6,
    0x37, 0xf1, 0x0c, 0xc3, 0x88, 0xd2, 0x50, 0xff, 0x19, 0x2d, 0xeb, 0x00,
    0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img4_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x02,
    0x1c, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x91, 0xbf, 0x4b, 0x5b,
    0x51, 0x1c, 0xc5, 0x3f, 0xf7, 0xbd, 0x67, 0x1b, 0xa1, 0x45, 0x24, 0xb8,
    0x48, 0x40, 0x74, 0x48, 0x87, 0xe2, 0x6a, 0xa1, 0x0e, 0xc5, 0xfc, 0x01,
    0x15, 0x27, 0x17, 0x67, 0x15, 0xa7, 0xf8, 0x7f, 0x28, 0x79, 0x83, 0x38,
    0x08, 0x05, 0xdb, 0x06, 0x17, 0xd7, 0x2a, 0xb8, 0x19, 0xe8, 0x8b, 0x50,
    0xba, 0x2a, 0x56, 0x3a, 0x59, 0x48, 0xb0, 0x12, 0xd4, 0x92, 0xf7, 0x7c,
    0x3f, 0xee, 0xfd, 0xde, 0x0e, 0xa9, 0x3f, 0x62, 0x6c, 0x97, 0x9e, 0xf1,
    0x5e, 0xce, 0x87, 0x73, 0xce, 0x57, 0x55, 0x2a, 0x15, 0xcb, 0x7f, 0xc8,
    0x03, 0x28, 0x97, 0xcb, 0x7c, 0xfa, 0x9a, 0xf2, 0xac, 0x1f, 0xda, 0xb1,
    0xe1, 0xcb, 0xf7, 0x88, 0x1f, 0xad, 0x84, 0x24, 0xd1, 0x84, 0xa9, 0x26,
    0x4c, 0x34, 0x51, 0x62, 0x88, 0x12, 0x4d, 0x3b, 0xc9, 0xf8, 0x15, 0x65,
    0xfc, 0x7c, 0xf7, 0x0a, 0xdf, 0xf7, 0x3b, 0x00, 0x80, 0x37, 0x2f, 0xfb,
    0xd0, 0x62, 0x51, 0x78, 0xbc, 0x7e, 0xf1, 0x04, 0x6d, 0x2c, 0x5a, 0x6b,
    0x8c, 0x58, 0x8c, 0x08, 0x62, 0x04, 0x23, 0x82, 0x36, 0x06, 0x63, 0xa4,
    0x3b, 0x01, 0xc0, 0xf3, 0x7e, 0x05, 0x28, 0xce, 0xcf, 0xcf, 0xa9, 0x07,
    0x9f, 0x79, 0x3b, 0x3d, 0x8d, 0xa2, 0x0f, 0x11, 0xc1, 0x8a, 0x41, 0xac,
    0x83, 0x15, 0x8b, 0x88, 0x03, 0xdc, 0xb5, 0x76, 0x1e, 0x76, 0x0a, 0x82,
    0x80, 0xf7, 0x1f, 0x3e, 0x72, 0x7c, 0xfc, 0x0d, 0x94, 0x4b, 0xa6, 0x85,
    0x54, 0x5b, 0x32, 0x6d, 0xd1, 0x02, 0xc6, 0x3a, 0xc4, 0xa9, 0x3c, 0x0e,
    0x68, 0x34, 0x1a, 0x34, 0x9b, 0x4d, 0xf2, 0xf9, 0x3c, 0x3b, 0x3b, 0x3b,
    0x00, 0x58, 0x6b, 0x51, 0x4a, 0xe1, 0x79, 0x1e, 0xad, 0x56, 0x8b, 0x8b,
    0x8b, 0x8b, 0xde, 0x11, 0x6f, 0x74, 0x70, 0x70, 0x40, 0xa9, 0x54, 0x62,
    0x6c, 0x6c, 0x8c, 0x95, 0x95, 0x15, 0x66, 0x66, 0x66, 0x18, 0x1d, 0x1d,
    0xa5, 0xdd, 0x6e, 0xb3, 0xb9, 0xb9, 0xc9, 0xf0, 0xf0, 0x30, 0xf5, 0x7a,
    0x9d, 0x38, 0x8e, 0x59, 0x5f, 0x5f, 0xef, 0x4e, 0x70, 0x79, 0x79, 0xc9,
    0xde, 0xde, 0x1e, 0xfb, 0xfb, 0xfb, 0x9c, 0x9c, 0x9c, 0x70, 0x76, 0x76,
    0xc6, 0xd6, 0xd6, 0x16, 0x8e, 0xe3, 0x90, 0x24, 0x09, 0xf9, 0x7c, 0x9e,
    0xc9, 0xc9, 0x49, 0x46, 0x46, 0x46, 0xa8, 0x56, 0xab, 0xbd, 0x09, 0xb6,
    0xb7, 0xb7, 0x99, 0x9a, 0x9a, 0xa2, 0x54, 0x2a, 0xa1, 0x94, 0x22, 0x0c,
    0x43, 0xaa, 0xd5, 0x2a, 0x73, 0x73, 0x73, 0x14, 0x0a, 0x05, 0xac, 0xb5,
    0x6c, 0x6c, 0x6c, 0x90, 0xa6, 0x29, 0xae, 0xeb, 0xf6, 0x6e, 0xb0, 0xb6,
    0xb6, 0x46, 0xb1, 0x58, 0x64, 0x70, 0x70, 0x90, 0xa1, 0xa1, 0x21, 0xc6,
    0xc7, 0xc7, 0x39, 0x3c, 0x3c, 0x64, 0x75, 0x75, 0x95, 0xa3, 0xa3, 0x23,
    0x96, 0x96, 0x96, 0x28, 0x14, 0x0a, 0x14, 0x8b, 0x45, 0xe2, 0x38, 0xee,
    0x05, 0x4c, 0x4c, 0x4c, 0x50, 0xab, 0xd5, 0xb8, 0xba, 0xba, 0x22, 0x0c,
    0x43, 0x1a, 0x8d, 0x06, 0xf3, 0xf3, 0xf3, 0x18, 0x63, 0x38, 0x3d, 0x3d,
    0x65, 0x71, 0x71, 0x91, 0x20, 0x08, 0x70, 0x5d, 0x97, 0x85, 0x85, 0x85,
    0x5b, 0x80, 0xaa, 0x54, 0x2a, 0xb6, 0x5c, 0x2e, 0x03, 0x70, 0x7d, 0x7d,
    0x8d, 0x31, 0xa6, 0xd3, 0xcd, 0xf3, 0xc8, 0xe5, 0x72, 0x88, 0x08, 0x59,
    0x96, 0x91, 0xa6, 0x29, 0xbb, 0xbb, 0xbb, 0x5d, 0x17, 0x68, 0x36, 0x9b,
    0x77, 0x1b, 0x44, 0x51, 0xd4, 0x89, 0xe4, 0x74, 0x42, 0x89, 0x48, 0xd7,
    0xdb, 0x4d, 0xec, 0xd9, 0xd9, 0x59, 0x00, 0x7c, 0xdf, 0x67, 0x79, 0x79,
    0xf9, 0xe9, 0x2d, 0xe0, 0xc6, 0xf8, 0x98, 0x1e, 0xfe, 0xfd, 0x31, 0xab,
    0xae, 0x2b, 0xe4, 0x72, 0xb9, 0xbf, 0x02, 0x00, 0x06, 0x06, 0x06, 0x7a,
    0xcc, 0xb7, 0x00, 0xdf, 0xf7, 0xff, 0x69, 0xbe, 0xaf, 0xfb, 0x66, 0x80,
    0xdf, 0xf6, 0x04, 0x0c, 0x6d, 0xbb, 0x99, 0x04, 0x79, 0x00, 0x00, 0x00,
    0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img5_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x03,
    0x18, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x93, 0x5f, 0x68, 0x5b,
    0x75, 0x00, 0x85, 0xbf, 0xe4, 0xa6, 0xd9, 0x92, 0x34, 0x6b, 0x5c, 0xd2,
    0x1a, 0xd7, 0xd6, 0xba, 0x6e, 0x2c, 0xb5, 0xc3, 0xa9, 0x1d, 0x6e, 0x63,
    0x1b, 0x45, 0x9d, 0x62, 0x2b, 0xac, 0x30, 0x75, 0x08, 0x0e, 0x04, 0x51,
    0x44, 0x51, 0xe6, 0x40, 0x10, 0x44, 0x9c, 0xec, 0x41, 0xd4, 0x17, 0x15,
    0xa6, 0x88, 0x50, 0x7d, 0x51, 0xca, 0x2a, 0xd8, 0xd9, 0x15, 0x37, 0x59,
    0x1b, 0x47, 0x61, 0x7f, 0x68, 0xb7, 0x75, 0x35, 0x59, 0x97, 0xae, 0x4d,
    0x4d, 0xd7, 0x96, 0x2e, 0x59, 0x93, 0x34, 0xb9, 0x49, 0x7a, 0x73, 0x6f,
    0xee, 0xfd, 0xfd, 0x7c, 0x10, 0xc7, 0x18, 0xec, 0xc9, 0xf3, 0x74, 0xe0,
    0xc0, 0xf7, 0xf4, 0x1d, 0x9b, 0x94, 0x92, 0xff, 0x13, 0xdb, 0xc0, 0xbe,
    0x7f, 0x8b, 0x5d, 0x42, 0x45, 0xc7, 0xab, 0xb8, 0x78, 0xe9, 0xbe, 0xe6,
    0x50, 0x87, 0xe6, 0x7f, 0xec, 0x89, 0x60, 0x63, 0xd0, 0xeb, 0xf2, 0xb8,
    0x50, 0x53, 0x8b, 0x56, 0x2e, 0x3e, 0x76, 0xfd, 0xf8, 0x70, 0xec, 0x74,
    0xef, 0x5f, 0x56, 0xcf, 0x2d, 0x83, 0xc4, 0x6d, 0xc2, 0xc0, 0x3e, 0x38,
    0xd1, 0x05, 0x27, 0xf6, 0xd2, 0x31, 0x7a, 0x64, 0xdb, 0x68, 0xfa, 0xca,
    0x2f, 0x72, 0x28, 0x9a, 0x93, 0xa3, 0x29, 0x21, 0xff, 0x9c, 0x17, 0x32,
    0x63, 0x0a, 0x29, 0x4c, 0x5d, 0x5a, 0xc9, 0x59, 0xa9, 0x4d, 0x9c, 0x94,
    0xe1, 0x23, 0x7b, 0xe6, 0x3a, 0x1a, 0x79, 0xfd, 0x36, 0xa0, 0xbf, 0x0b,
    0x06, 0x5e, 0x50, 0xde, 0x98, 0x3f, 0xfe, 0xb6, 0x10, 0x22, 0x25, 0x85,
    0x28, 0xcb, 0xbd, 0xfd, 0x42, 0xee, 0x08, 0x0b, 0xd9, 0xda, 0x2b, 0xe4,
    0xb9, 0x2b, 0x51, 0x29, 0x8e, 0x7d, 0x20, 0xc5, 0xf9, 0x6e, 0x29, 0xfa,
    0x3e, 0x97, 0x42, 0x8d, 0xcb, 0x78, 0xcf, 0x5b, 0xa2, 0xfd, 0x01, 0x0e,
    0x02, 0x28, 0xaf, 0x84, 0xd8, 0xd5, 0xd4, 0xde, 0xde, 0x7b, 0x35, 0x91,
    0xbb, 0xd1, 0xf7, 0xdd, 0xd7, 0xd7, 0x6a, 0x4b, 0x97, 0x3c, 0xab, 0xb6,
    0x3c, 0xec, 0x2e, 0xbb, 0xdd, 0xd4, 0xad, 0xce, 0x72, 0xc0, 0x3f, 0x83,
    0xfb, 0xe2, 0x51, 0x28, 0x8c, 0x51, 0x99, 0x1a, 0xc6, 0xb6, 0x71, 0x1b,
    0x6b, 0x1f, 0xdd, 0x6e, 0xdb, 0xcc, 0xd4, 0xd3, 0xa7, 0x2e, 0xcc, 0x9d,
    0x51, 0x0e, 0xbd, 0xb8, 0xb1, 0xdb, 0xb9, 0xae, 0x39, 0xf4, 0xe6, 0x47,
    0xbf, 0xbf, 0x36, 0x18, 0xc9, 0x7c, 0xa2, 0x25, 0xa2, 0x0f, 0x7d, 0x7c,
    0xa0, 0x65, 0x6b, 0xa7, 0x2f, 0xc3, 0x7e, 0x4f, 0x0c, 0xb7, 0xbd, 0x00,
    0xc1, 0x06, 0x2a, 0x81, 0x10, 0xb2, 0xa1, 0x09, 0xc5, 0xe1, 0xc2, 0xe6,
    0xd9, 0x40, 0x7d, 0xc0, 0xe5, 0x58, 0xbc, 0x34, 0x58, 0xe3, 0xa8, 0x7d,
    0xbc, 0x6d, 0x67, 0x70, 0xfb, 0x6e, 0x8e, 0x1e, 0x8a, 0x7d, 0xa6, 0x2f,
    0x67, 0xdf, 0x6d, 0xdc, 0xd2, 0xd2, 0x26, 0x45, 0x11, 0x67, 0x3e, 0x0a,
    0x15, 0x03, 0x2c, 0x0b, 0xb0, 0x53, 0x65, 0xb7, 0xa0, 0x4a, 0x80, 0xfa,
    0x23, 0xd4, 0x8f, 0x80, 0x35, 0xc9, 0xee, 0x90, 0x77, 0xa7, 0x43, 0x29,
    0x24, 0x95, 0xd5, 0x75, 0x55, 0x3c, 0x7b, 0xf0, 0xe5, 0x56, 0xf2, 0xf9,
    0x56, 0x10, 0xa0, 0x26, 0xc0, 0xd0, 0xc1, 0x34, 0xc0, 0xac, 0x80, 0x65,
    0x42, 0xc5, 0x04, 0xc3, 0x00, 0xff, 0x02, 0x28, 0x2e, 0xa4, 0x4c, 0x10,
    0xf0, 0x2a, 0xd5, 0x8a, 0x4c, 0xdd, 0x5c, 0xb3, 0xd9, 0xb1, 0xb4, 0xa3,
    0xc6, 0x85, 0x1d, 0x27, 0x50, 0xc8, 0x42, 0x29, 0x0b, 0x5a, 0x0e, 0x56,
    0x96, 0x61, 0x25, 0x03, 0xa5, 0x34, 0x14, 0xd3, 0x50, 0x4a, 0x53, 0x56,
    0x7d, 0x94, 0x6f, 0x54, 0xb1, 0x6a, 0x36, 0x43, 0x62, 0x56, 0xd5, 0x95,
    0x91, 0x05, 0x2b, 0x7c, 0xf6, 0xdc, 0xc2, 0xc8, 0xc4, 0xe8, 0xa4, 0xb5,
    0x4e, 0xaa, 0x2d, 0xf7, 0x07, 0xab, 0x1d, 0x58, 0x06, 0x94, 0x57, 0xc0,
    0xd0, 0x40, 0x57, 0x91, 0xea, 0x32, 0xb6, 0x72, 0x81, 0x71, 0xbd, 0xc2,
    0xcc, 0xae, 0xc3, 0x14, 0x9b, 0x3a, 0xa9, 0x4c, 0xf5, 0x13, 0x1f, 0x57,
    0x33, 0x0a, 0xc0, 0xa2, 0xc6, 0xcc, 0xc8, 0x82, 0xf5, 0xdb, 0xf0, 0xc5,
    0xf4, 0xc4, 0x26, 0x25, 0xf3, 0xd4, 0x86, 0xf5, 0x6b, 0xaa, 0x31, 0x74,
    0x28, 0x17, 0x11, 0xd2, 0xc7, 0x4a, 0xa0, 0x0b, 0xa7, 0x34, 0xf9, 0x49,
    0xc4, 0xf9, 0xa2, 0x2d, 0xcf, 0x40, 0x4d, 0x84, 0x5c, 0xf4, 0x1a, 0xea,
    0x19, 0xf3, 0xbc, 0x72, 0xa7, 0x96, 0x69, 0x9d, 0xc9, 0xcb, 0xd3, 0xda,
    0xf5, 0x27, 0xeb, 0xcd, 0xfd, 0x75, 0x41, 0x87, 0x5d, 0xe4, 0x4a, 0xc4,
    0xb2, 0x1f, 0x62, 0x3c, 0xf2, 0x3e, 0x4b, 0xa9, 0x67, 0xf0, 0x2d, 0x7d,
    0xcf, 0xec, 0x26, 0x03, 0x9f, 0x50, 0x69, 0x3b, 0x75, 0x93, 0x9f, 0x87,
    0xf8, 0xd6, 0x71, 0xb7, 0xdb, 0xb1, 0x3c, 0x03, 0xdd, 0x7f, 0x24, 0x7b,
    0xbe, 0x7c, 0xd0, 0xf6, 0xaa, 0xdd, 0x61, 0x92, 0x9c, 0xae, 0xa1, 0x62,
    0x42, 0x7e, 0xda, 0x4f, 0xa7, 0xd7, 0xc9, 0xb1, 0xbe, 0x39, 0xf4, 0xb2,
    0xc2, 0xe1, 0xd3, 0x8c, 0x45, 0x54, 0x7e, 0x55, 0xee, 0x06, 0x00, 0xcc,
    0xe7, 0x18, 0xf7, 0xea, 0xda, 0x73, 0x21, 0xbf, 0x59, 0xdb, 0xe8, 0x8b,
    0x10, 0x68, 0xd0, 0x68, 0x96, 0x9f, 0xb2, 0xd6, 0x7d, 0x95, 0x62, 0x46,
    0xf0, 0x4d, 0xd8, 0x9a, 0xfa, 0x6a, 0x9c, 0xf7, 0x74, 0x41, 0xc4, 0x76,
    0xaf, 0x97, 0x79, 0x14, 0x9a, 0x9f, 0x5f, 0xcf, 0x3b, 0x5b, 0xeb, 0xd9,
    0x13, 0xf0, 0x50, 0xe7, 0x71, 0x62, 0x4b, 0xaa, 0x68, 0xe1, 0xbf, 0x19,
    0x1c, 0x9a, 0xe3, 0x87, 0xb2, 0xe0, 0x32, 0x60, 0xdd, 0x13, 0x70, 0x47,
    0x02, 0x40, 0x35, 0x60, 0x03, 0x04, 0x70, 0x0b, 0xd0, 0xfe, 0x1b, 0xff,
    0x01, 0xd8, 0x2e, 0x7e, 0x2b, 0x96, 0x2d, 0x48, 0xb6, 0x00, 0x00, 0x00,
    0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img6_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x02,
    0xcd, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0x6d, 0x93, 0x51, 0x68, 0x5b,
    0x55, 0x18, 0xc7, 0x7f, 0xe7, 0xdc, 0x93, 0x9b, 0x9b, 0x2c, 0xed, 0x6d,
    0xd2, 0x9a, 0xa4, 0xc5, 0x6e, 0xa3, 0xc9, 0xec, 0xa6, 0x28, 0x25, 0xd0,
    0x97, 0x39, 0x86, 0xb8, 0x07, 0xa1, 0x32, 0x11, 0x44, 0x1f, 0xf6, 0x52,
    0x10, 0xca, 0xb6, 0x87, 0xfa, 0xb4, 0xc7, 0xe1, 0x04, 0x71, 0x2f, 0xe2,
    0xd3, 0xf6, 0xe4, 0x85, 0x41, 0x71, 0x0e, 0x04, 0x11, 0xa4, 0x7b, 0x1a,
    0x08, 0x7b, 0x98, 0x32, 0x37, 0xb5, 0x1d, 0x8a, 0x46, 0xb6, 0xe2, 0xda,
    0x95, 0x35, 0x4b, 0x8c, 0x49, 0x6e, 0xda, 0x4b, 0xef, 0x4d, 0xce, 0xbd,
    0x7b, 0x88, 0xeb, 0x58, 0x97, 0x0f, 0xbe, 0xa7, 0xef, 0xff, 0xfb, 0xf3,
    0x1d, 0xfe, 0xe7, 0x13, 0xf4, 0xa9, 0xd2, 0xe9, 0x3b, 0x16, 0x84, 0xd3,
    0x44, 0x61, 0x11, 0x22, 0x01, 0xe1, 0x8a, 0xd2, 0xed, 0xdb, 0xb7, 0x9c,
    0x63, 0xde, 0x6e, 0xad, 0xd8, 0x05, 0xa6, 0x40, 0x9c, 0xc5, 0x88, 0x9d,
    0x92, 0xe6, 0xa0, 0x3d, 0x9e, 0xee, 0x90, 0x8c, 0x75, 0xf9, 0xbb, 0x6a,
    0x11, 0xfa, 0xcd, 0x96, 0xd0, 0xde, 0x37, 0x4a, 0x37, 0x3e, 0xfb, 0xd9,
    0x79, 0x6b, 0xed, 0x39, 0x83, 0xd2, 0xe9, 0x3b, 0x79, 0x84, 0xbc, 0x9e,
    0xcb, 0x0e, 0x4f, 0xce, 0xbe, 0x69, 0x73, 0xe4, 0x90, 0xc1, 0x60, 0xd2,
    0x00, 0xc0, 0xef, 0x44, 0xfc, 0x76, 0xcf, 0xe3, 0xd2, 0x0f, 0x9b, 0xdc,
    0xbd, 0x5f, 0xfd, 0x37, 0xa1, 0x2b, 0xef, 0xff, 0xf8, 0xe5, 0xcc, 0x75,
    0x00, 0xa3, 0x07, 0x2f, 0xa7, 0x10, 0xf2, 0xa7, 0xd2, 0xcb, 0x63, 0x93,
    0x1f, 0x7f, 0xb0, 0x87, 0x42, 0x5e, 0x31, 0xfe, 0x42, 0x9c, 0x33, 0x57,
    0x24, 0xa5, 0x7d, 0x1d, 0x3a, 0x3a, 0x62, 0xc4, 0x56, 0xbc, 0xf1, 0xaa,
    0x85, 0xbb, 0x6d, 0x24, 0xcb, 0x1b, 0xe2, 0xf8, 0x81, 0xd7, 0x8e, 0x7e,
    0xb5, 0xba, 0xf4, 0xdd, 0xa6, 0x01, 0x30, 0x3a, 0x7d, 0xf2, 0x7c, 0x2e,
    0x97, 0x3d, 0xfe, 0xd1, 0x8c, 0x85, 0x40, 0xe2, 0xf9, 0x21, 0xa3, 0xc3,
    0x26, 0x33, 0x53, 0x70, 0xf6, 0x5b, 0xc5, 0x64, 0xd6, 0xc7, 0xf3, 0x43,
    0xfc, 0x20, 0xe2, 0xe0, 0x78, 0x9c, 0x7b, 0x8f, 0x8c, 0x64, 0xa5, 0xc5,
    0xc0, 0xdb, 0x25, 0xe3, 0x9a, 0x51, 0x3a, 0xf5, 0x8b, 0x85, 0x11, 0xbf,
    0xf2, 0xde, 0x11, 0xdb, 0x1a, 0x4c, 0x82, 0xe7, 0x6b, 0x3c, 0x5f, 0x53,
    0x1c, 0x4b, 0x00, 0x30, 0x33, 0x05, 0xe7, 0xaf, 0x9a, 0xbc, 0x68, 0x6f,
    0xf5, 0x66, 0xdb, 0x21, 0x76, 0xa2, 0xcb, 0xaf, 0x2b, 0xd1, 0xa4, 0x0e,
    0x36, 0x2f, 0x2b, 0x60, 0xda, 0xb4, 0x52, 0x76, 0x3a, 0xa1, 0xa9, 0x35,
    0xc3, 0x7e, 0xa1, 0x70, 0x61, 0x16, 0xe6, 0x17, 0xd2, 0x1c, 0x4a, 0x6f,
    0x70, 0xf5, 0xcf, 0x0c, 0xae, 0x9f, 0x46, 0xc6, 0xa3, 0x94, 0x1b, 0x14,
    0x0e, 0x2b, 0xa0, 0x98, 0x49, 0x49, 0x6a, 0x6e, 0x17, 0x43, 0x08, 0x0c,
    0xd9, 0xd7, 0x83, 0x0b, 0xb3, 0xf0, 0xee, 0xe7, 0x43, 0xb4, 0x83, 0x38,
    0x00, 0x32, 0x66, 0x21, 0xa4, 0x2a, 0x2a, 0x40, 0x04, 0xda, 0x60, 0xad,
    0x6e, 0x60, 0x2a, 0x81, 0xa9, 0x04, 0x35, 0xcf, 0xea, 0x6b, 0x32, 0x9e,
    0x4d, 0x50, 0x5f, 0x05, 0x21, 0x7a, 0xf1, 0x09, 0x22, 0xa9, 0x20, 0x5c,
    0x69, 0x79, 0x11, 0xe5, 0xfa, 0xc8, 0x8e, 0x30, 0xea, 0x03, 0xcf, 0x2f,
    0xc0, 0xf2, 0xff, 0xb0, 0x21, 0x60, 0xbb, 0xeb, 0x63, 0x86, 0xde, 0xba,
    0x54, 0xba, 0x7d, 0x5b, 0xfb, 0xcd, 0x96, 0x14, 0x20, 0x65, 0xaf, 0x77,
    0x3f, 0x63, 0x7e, 0x01, 0xfe, 0x78, 0x10, 0x61, 0xc5, 0x34, 0x89, 0x98,
    0xc6, 0x52, 0x9a, 0x70, 0xbb, 0xb1, 0x95, 0xd1, 0xe5, 0x25, 0x79, 0xcb,
    0x39, 0xe6, 0x09, 0xed, 0x5d, 0x92, 0x7e, 0x85, 0xbd, 0x83, 0xee, 0x4e,
    0x3f, 0xa9, 0x2f, 0xbe, 0x6f, 0x13, 0x78, 0x0d, 0x5e, 0x1a, 0x6e, 0x32,
    0x31, 0xe4, 0xb2, 0xdf, 0x76, 0x91, 0x7e, 0x85, 0x58, 0xb7, 0xb6, 0x98,
    0x55, 0xab, 0x0f, 0x15, 0x80, 0xd2, 0x8d, 0x4f, 0xab, 0x55, 0xf9, 0xce,
    0xc4, 0xc8, 0x48, 0x21, 0x63, 0x9b, 0x3b, 0xf0, 0xb9, 0xcb, 0x1b, 0x00,
    0xe4, 0x07, 0x9e, 0x6e, 0xf3, 0x5f, 0x2b, 0xa0, 0xfa, 0xa8, 0xb6, 0x3e,
    0xd6, 0xbd, 0x79, 0x11, 0x83, 0xfa, 0xce, 0x57, 0x7e, 0x7d, 0x6e, 0xb1,
    0x10, 0xc4, 0x46, 0xaf, 0x4d, 0x15, 0xed, 0x89, 0x83, 0x7b, 0x53, 0x08,
    0xf1, 0xcc, 0x99, 0x10, 0x45, 0x11, 0xe5, 0xb5, 0x4d, 0x96, 0xef, 0x36,
    0xd6, 0xf3, 0x9d, 0x1b, 0x27, 0xf3, 0xe2, 0xaf, 0x1b, 0x8e, 0xe3, 0xb8,
    0xcf, 0xa8, 0x8e, 0x7e, 0xf8, 0xf5, 0xa8, 0x17, 0xdb, 0xf7, 0x49, 0x32,
    0xb9, 0xe7, 0xc4, 0xfe, 0x9c, 0x99, 0x1a, 0x1a, 0xe8, 0x45, 0xd6, 0x6c,
    0xfb, 0xdc, 0xaf, 0x04, 0x5b, 0xbe, 0xd7, 0x58, 0xcc, 0x75, 0x6f, 0x5e,
    0xcc, 0x19, 0xff, 0xfc, 0xee, 0x38, 0x8e, 0x0b, 0xbb, 0xae, 0x11, 0x60,
    0x6e, 0x6e, 0xce, 0x7c, 0xd0, 0x7d, 0x65, 0xcc, 0x35, 0x0a, 0x87, 0x85,
    0x54, 0x45, 0x41, 0x24, 0x45, 0xe8, 0xad, 0x67, 0x74, 0x79, 0x29, 0xab,
    0x56, 0x1f, 0x02, 0x75, 0xc7, 0x71, 0x82, 0x27, 0xfa, 0xc7, 0x08, 0x00,
    0x19, 0xff, 0xd8, 0xe8, 0x85, 0x82, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
    0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img7_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x02,
    0xb0, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0x8d, 0x91, 0x49, 0x4c, 0x13,
    0x01, 0x14, 0x86, 0xff, 0x59, 0x3b, 0x53, 0x2c, 0x53, 0xa4, 0x56, 0x28,
    0xb4, 0x20, 0x52, 0x13, 0xca, 0x2a, 0x21, 0x1a, 0x82, 0x07, 0xe3, 0x85,
    0x83, 0x21, 0x72, 0x34, 0xc1, 0x28, 0x07, 0xa2, 0xf1, 0x60, 0x88, 0x5e,
    0x34, 0x1e, 0x4c, 0xd4, 0x18, 0x3d, 0x10, 0x0f, 0x18, 0x2f, 0xc2, 0x4d,
    0xd2, 0x93, 0x78, 0x30, 0x1a, 0x12, 0x40, 0x30, 0x81, 0xb8, 0x20, 0x20,
    0x11, 0x41, 0xd6, 0x32, 0x6c, 0xc5, 0x52, 0x6a, 0xf7, 0x4e, 0xa7, 0xed,
    0xcc, 0x78, 0xb1, 0x98, 0x46, 0x23, 0xfc, 0xc9, 0xbb, 0xbc, 0x97, 0xf7,
    0xe5, 0x7d, 0x79, 0xc0, 0x1e, 0x19, 0x1b, 0x9b, 0xbd, 0x32, 0x31, 0x31,
    0xef, 0x1f, 0x1d, 0x9d, 0xae, 0xfa, 0xd7, 0x9c, 0xdc, 0x0b, 0xc0, 0xf3,
    0xdc, 0x9d, 0xec, 0xec, 0x2c, 0xa3, 0x2c, 0x27, 0x76, 0x7b, 0x7d, 0x7d,
    0x1f, 0x4f, 0x0d, 0x0e, 0x8e, 0x9f, 0x01, 0x00, 0x7a, 0x2f, 0x00, 0x4d,
    0x93, 0x16, 0x49, 0x92, 0x11, 0x08, 0x44, 0xd0, 0xd1, 0xe1, 0xa4, 0x2c,
    0x16, 0x53, 0x43, 0x7e, 0xbe, 0xa9, 0x9b, 0xe3, 0xd8, 0x97, 0x00, 0x86,
    0xf6, 0xbc, 0x20, 0x14, 0x8a, 0x21, 0x14, 0x8a, 0xc2, 0xeb, 0xf5, 0xd3,
    0x82, 0x70, 0xe0, 0xac, 0xdd, 0x6e, 0xed, 0xb6, 0xd9, 0xcc, 0x45, 0xdb,
    0xdb, 0xfe, 0xc0, 0xbe, 0x14, 0x82, 0xc1, 0x28, 0x82, 0xc1, 0x08, 0x3c,
    0x1e, 0x5f, 0x43, 0x59, 0x59, 0x51, 0x87, 0xd5, 0x7a, 0xd8, 0x3e, 0x35,
    0xb5, 0x34, 0xb9, 0xb8, 0xb8, 0xd6, 0xbb, 0x2f, 0x05, 0x9f, 0x2f, 0x08,
    0x45, 0x51, 0xe0, 0x70, 0x94, 0x3c, 0x14, 0x04, 0x03, 0x37, 0x3c, 0x3c,
    0xf1, 0xd9, 0xed, 0xde, 0xb9, 0xc4, 0xf3, 0xec, 0xd2, 0x5f, 0x80, 0xa1,
    0x5b, 0x85, 0x06, 0x86, 0x26, 0xec, 0x1c, 0x0b, 0x96, 0xa5, 0x21, 0x56,
    0xdf, 0x5e, 0xff, 0xb1, 0xb2, 0xbc, 0x8a, 0x42, 0x9b, 0x05, 0x26, 0x93,
    0xc0, 0x0f, 0x0e, 0x8e, 0x8d, 0xb8, 0x5c, 0x9b, 0xd7, 0x09, 0x82, 0x58,
    0xec, 0xec, 0xbc, 0xa1, 0x65, 0x00, 0x5e, 0xb5, 0x17, 0x16, 0x09, 0x66,
    0x74, 0x1c, 0xad, 0x25, 0x2b, 0x99, 0x5c, 0x86, 0x0a, 0x2e, 0xaa, 0xcb,
    0xf3, 0x8f, 0x6d, 0x3d, 0xef, 0xb9, 0x04, 0x54, 0x55, 0x43, 0x7f, 0xff,
    0xa7, 0x39, 0x51, 0x74, 0x5f, 0x23, 0x08, 0x72, 0xc6, 0xe9, 0xbc, 0xab,
    0xa5, 0xf7, 0x08, 0x00, 0xe8, 0xba, 0x50, 0x60, 0xab, 0x75, 0x24, 0x5f,
    0x17, 0x1f, 0x23, 0xac, 0x91, 0x30, 0xf3, 0xcd, 0x68, 0x61, 0x8c, 0xbc,
    0x95, 0xae, 0x50, 0x08, 0x1a, 0x1f, 0x16, 0x6a, 0x30, 0x37, 0xc6, 0x42,
    0x27, 0x6f, 0x34, 0x9f, 0x3c, 0xb4, 0x30, 0xa2, 0x01, 0x81, 0xca, 0x9b,
    0xeb, 0x6a, 0x1a, 0x40, 0x01, 0x40, 0x6b, 0x3d, 0xd7, 0xe6, 0xb0, 0xc5,
    0x9b, 0x27, 0x67, 0x74, 0x5d, 0x5e, 0x0f, 0x79, 0x35, 0xd7, 0x88, 0x79,
    0x9d, 0x01, 0x2d, 0xba, 0x83, 0x24, 0x8c, 0xb2, 0x1b, 0x55, 0xa5, 0xeb,
    0x70, 0xd8, 0x03, 0x25, 0x3a, 0x81, 0xac, 0x8f, 0x47, 0x35, 0x7f, 0x6b,
    0x7d, 0xf6, 0x6a, 0xd7, 0x70, 0xe8, 0x8f, 0x42, 0x5e, 0x96, 0x94, 0x97,
    0x08, 0xa5, 0xc8, 0x79, 0x17, 0xc6, 0xb3, 0xf4, 0x2a, 0xf2, 0xb7, 0xd4,
    0x26, 0xc1, 0xac, 0xa8, 0xe2, 0x9c, 0x3a, 0x97, 0x6d, 0x21, 0x1d, 0x42,
    0x29, 0xad, 0x21, 0x8c, 0x72, 0x7d, 0x2e, 0x59, 0x23, 0xc7, 0xc9, 0xe3,
    0x52, 0x4c, 0x39, 0x0d, 0xc0, 0xb3, 0xfb, 0xc6, 0x6d, 0x3f, 0x15, 0xd6,
    0x69, 0x49, 0xf6, 0x44, 0x49, 0xf8, 0x51, 0xe5, 0x91, 0xd8, 0x40, 0x8e,
    0x5e, 0xbe, 0x28, 0x7e, 0x57, 0xfa, 0x97, 0xbe, 0x2a, 0xe7, 0x95, 0x70,
    0x12, 0xa1, 0x99, 0xf8, 0x8a, 0xf8, 0x2e, 0x71, 0x79, 0x7b, 0x32, 0xe1,
    0x14, 0xf4, 0xa9, 0x52, 0x39, 0xa1, 0x35, 0xa6, 0x15, 0x68, 0x00, 0x58,
    0xf0, 0x72, 0xbd, 0x2c, 0xa5, 0xd5, 0x15, 0x98, 0x93, 0x8d, 0x2a, 0x41,
    0x18, 0xc4, 0x75, 0xe6, 0x99, 0x3f, 0x42, 0x3e, 0x49, 0xa5, 0x20, 0x4a,
    0x3b, 0x49, 0x28, 0x0c, 0x46, 0x5c, 0x6b, 0xec, 0x1b, 0x8a, 0xd6, 0x02,
    0x15, 0x7c, 0xa2, 0x49, 0x8a, 0xd3, 0xe6, 0x0c, 0x40, 0x54, 0xa6, 0x66,
    0xa7, 0xb7, 0xf4, 0x2d, 0x20, 0x25, 0x5e, 0x06, 0xa3, 0xfe, 0x94, 0x98,
    0x48, 0xdb, 0x73, 0x77, 0x1c, 0x00, 0xbe, 0x3c, 0x30, 0xad, 0xf1, 0x4c,
    0xaa, 0x5a, 0xdc, 0x20, 0xca, 0x8b, 0xf3, 0x53, 0x55, 0x71, 0x4f, 0xd2,
    0x10, 0x0d, 0x93, 0xb1, 0x0c, 0xc0, 0xbd, 0x01, 0xb7, 0x06, 0x20, 0xfc,
    0xbb, 0x32, 0xb2, 0xb9, 0x85, 0x17, 0xe5, 0x16, 0xb9, 0xbd, 0xae, 0x38,
    0xd9, 0x93, 0xc5, 0xa9, 0x66, 0x9f, 0x87, 0xf6, 0xc7, 0x24, 0xed, 0x6d,
    0x06, 0xe0, 0x7f, 0xd9, 0xf4, 0x51, 0x4f, 0x93, 0x71, 0xae, 0xa8, 0x38,
    0x47, 0x3a, 0xb7, 0x15, 0xa1, 0xbd, 0xab, 0x7e, 0xdd, 0x7d, 0x6f, 0x84,
    0x72, 0xa5, 0xe7, 0xbf, 0x00, 0x42, 0x81, 0x2c, 0x0f, 0xf7, 0x19, 0x0a,
    0xd5, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60,
    0x82
};

static const unsigned char img8_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x0f,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x3b, 0xd6, 0x95, 0x4a, 0x00, 0x00, 0x00,
    0xfc, 0x49, 0x44, 0x41, 0x54, 0x28, 0x91, 0x63, 0x64, 0xc0, 0x01, 0x98,
    0x9c, 0xd2, 0xfe, 0xc3, 0xd8, 0xff, 0xf6, 0xcd, 0x62, 0xc4, 0xa5, 0x0e,
    0xab, 0xc6, 0x75, 0x77, 0x5f, 0xfe, 0x5f, 0x77, 0xf7, 0xe5, 0xff, 0xbe,
    0x13, 0x77, 0xfe, 0x23, 0x1b, 0x84, 0x0c, 0x58, 0xf0, 0x19, 0x72, 0xfd,
    0xf1, 0x5b, 0xbc, 0x96, 0xe0, 0xd5, 0xfc, 0xfd, 0xc7, 0x4f, 0x4a, 0x34,
    0xff, 0x26, 0xac, 0x19, 0x97, 0x9f, 0xbe, 0xff, 0xf8, 0x05, 0x67, 0xa3,
    0xab, 0xf9, 0xb7, 0x6f, 0x16, 0x23, 0x23, 0x93, 0x53, 0xda, 0xff, 0x35,
    0xb3, 0x9b, 0x31, 0x34, 0x9e, 0xba, 0xf6, 0x88, 0xe1, 0xe5, 0xdb, 0xcf,
    0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0xac, 0x2c, 0x4c, 0x0c, 0x52, 0x22, 0x7c,
    0x0c, 0xf2, 0x92, 0x42, 0x0c, 0x9c, 0xec, 0xac, 0x0c, 0x57, 0xee, 0x3d,
    0x67, 0x68, 0xeb, 0x99, 0x85, 0x70, 0xf6, 0xaa, 0xdd, 0xe7, 0x70, 0x3b,
    0x9f, 0x81, 0x81, 0xe1, 0xd3, 0x97, 0xef, 0x0c, 0x37, 0x1e, 0xbc, 0xc4,
    0x74, 0xf6, 0x95, 0xdb, 0xcf, 0x18, 0xbe, 0x7f, 0xc7, 0xef, 0x3f, 0x6c,
    0x80, 0x91, 0x81, 0x81, 0x81, 0x81, 0xdd, 0x3d, 0xf3, 0xff, 0xef, 0xdf,
    0x7f, 0x51, 0x24, 0x02, 0x02, 0xfc, 0x19, 0x3e, 0x7f, 0xf9, 0xc6, 0xc0,
    0xc8, 0xc8, 0xc8, 0xb0, 0x67, 0xf7, 0x2e, 0x0c, 0x8d, 0xff, 0xf6, 0xcd,
    0x62, 0x64, 0x61, 0x60, 0x60, 0x60, 0xf8, 0xb9, 0x73, 0x3a, 0x4a, 0x0a,
    0x62, 0x72, 0x4a, 0xfb, 0xcf, 0xc7, 0xcb, 0xc1, 0xf0, 0xfa, 0xed, 0x47,
    0x14, 0xc5, 0xe8, 0x06, 0xe0, 0x8c, 0xaa, 0x6f, 0xdf, 0x7f, 0x91, 0x1f,
    0xcf, 0x4f, 0x5f, 0xbc, 0x23, 0x2e, 0x9e, 0xb1, 0x81, 0xe7, 0x2f, 0xdf,
    0xe3, 0xd5, 0xc8, 0xc0, 0x00, 0x0d, 0x30, 0x6c, 0x80, 0x98, 0x5c, 0x05,
    0x00, 0x8a, 0x86, 0x66, 0xd9, 0xd9, 0x8a, 0xa8, 0x19, 0x00, 0x00, 0x00,
    0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const unsigned char img9_configure[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x12,
    0x08, 0x06, 0x00, 0x00, 0x00, 0xbd, 0xf9, 0x35, 0x54, 0x00, 0x00, 0x02,
    0x27, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0x9d, 0xd2, 0x4f, 0x48, 0xd3,
    0x61, 0x18, 0xc0, 0xf1, 0xef, 0xef, 0x97, 0xca, 0x0a, 0xff, 0xe5, 0x82,
    0x22, 0x0c, 0x9a, 0x82, 0x59, 0x66, 0xed, 0x20, 0x25, 0x1d, 0x86, 0x51,
    0x20, 0x81, 0xc1, 0x82, 0x9d, 0xa2, 0xc3, 0x3a, 0x64, 0x07, 0x0f, 0xa5,
    0xd0, 0xa5, 0x0e, 0x5b, 0x5d, 0x0a, 0x42, 0x72, 0x75, 0x08, 0xba, 0x48,
    0x07, 0x3b, 0x49, 0x18, 0x51, 0x14, 0x44, 0x1b, 0x24, 0xb5, 0x9c, 0xe5,
    0x24, 0x10, 0x29, 0x64, 0x30, 0x41, 0xf1, 0xb7, 0x7f, 0xbf, 0xad, 0xed,
    0x37, 0x75, 0x9b, 0x6f, 0x87, 0xe5, 0xdc, 0x3f, 0x5d, 0xf4, 0xc2, 0x03,
    0xef, 0xe1, 0x79, 0x3e, 0xef, 0xc3, 0xf3, 0x3e, 0x92, 0x10, 0x02, 0x49,
    0x92, 0x28, 0x3e, 0x1e, 0x30, 0xd7, 0x18, 0x0c, 0xb6, 0x3a, 0x93, 0xc9,
    0x28, 0xd7, 0xd7, 0xb3, 0x01, 0xf8, 0xc6, 0xc6, 0x5c, 0xe7, 0xc2, 0xe1,
    0xb3, 0x9b, 0x39, 0x42, 0x88, 0xa2, 0x4b, 0x21, 0x60, 0x5c, 0x30, 0x99,
    0x84, 0xf0, 0x78, 0x84, 0x98, 0x9e, 0xce, 0xc5, 0xc2, 0xd0, 0x90, 0x78,
    0x09, 0x3d, 0xf9, 0x88, 0x10, 0x02, 0xb9, 0x44, 0x00, 0xd2, 0x60, 0xde,
    0xd7, 0xd7, 0x07, 0xa1, 0x50, 0x41, 0xb4, 0xf4, 0xf6, 0xa2, 0x6b, 0x6e,
    0x7e, 0x54, 0x9c, 0xbf, 0x1d, 0xe2, 0x4a, 0xb9, 0xdd, 0x10, 0x0c, 0x96,
    0xc4, 0x71, 0x8b, 0xc5, 0xf8, 0x1c, 0xac, 0x15, 0x91, 0x14, 0x34, 0x0a,
    0x4d, 0xcb, 0x16, 0x06, 0x02, 0x05, 0xc8, 0x21, 0x83, 0x81, 0xfd, 0xed,
    0xed, 0xb6, 0xa7, 0xd0, 0xb8, 0x99, 0x5f, 0x05, 0xf0, 0x75, 0xfc, 0x61,
    0xa4, 0xe6, 0xdb, 0x0b, 0x57, 0xfc, 0xfe, 0xcc, 0x6c, 0x0a, 0x1a, 0xea,
    0x74, 0x3a, 0x6b, 0x53, 0x6b, 0x6b, 0xb6, 0x10, 0xa0, 0x68, 0xf0, 0x9d,
    0x5d, 0x5d, 0x87, 0x7f, 0xcd, 0xcf, 0xdf, 0x04, 0xec, 0x39, 0xe4, 0x60,
    0x62, 0x1c, 0xdd, 0xc5, 0x0b, 0xe6, 0x5d, 0x33, 0xc2, 0x5c, 0xab, 0xd5,
    0x53, 0xd5, 0xd2, 0x82, 0x94, 0x4e, 0x67, 0xbb, 0xf8, 0x0b, 0xac, 0xb8,
    0xdd, 0x78, 0xbd, 0x5e, 0x35, 0x03, 0x5e, 0xa1, 0xd7, 0x23, 0xc1, 0x8d,
    0x02, 0x44, 0x8b, 0x46, 0x1d, 0x0d, 0x72, 0xd2, 0x16, 0xe8, 0x39, 0xc0,
    0xde, 0xa9, 0x3d, 0x10, 0x8b, 0x6d, 0x3d, 0x2b, 0x49, 0x24, 0xfd, 0x7e,
    0x3e, 0x78, 0xbd, 0x13, 0x1a, 0x5c, 0xed, 0x07, 0x95, 0x50, 0x08, 0x80,
    0x81, 0xfc, 0x99, 0xac, 0x67, 0xe4, 0x11, 0xe5, 0xc7, 0xa4, 0xba, 0xbb,
    0xfb, 0x24, 0xd1, 0xcc, 0x72, 0xb6, 0x83, 0xbc, 0x58, 0x54, 0x14, 0x12,
    0xe0, 0xe8, 0x07, 0xb5, 0xdc, 0x0c, 0x65, 0x80, 0xce, 0xc1, 0x39, 0x35,
    0x1c, 0x4a, 0x38, 0x74, 0xf2, 0x6f, 0xc2, 0xa7, 0xf4, 0x25, 0x48, 0x54,
    0xd3, 0xb8, 0x0e, 0xae, 0x72, 0x40, 0xc1, 0xef, 0x6c, 0x64, 0x18, 0x59,
    0x9e, 0xfd, 0xac, 0xd6, 0x9e, 0x3f, 0x4d, 0xb8, 0x3a, 0xba, 0x85, 0x28,
    0x0a, 0xc9, 0xd5, 0xd5, 0xed, 0xea, 0x0b, 0x91, 0xee, 0x3b, 0x73, 0xaa,
    0x12, 0x58, 0x1f, 0x94, 0x63, 0x0b, 0x2c, 0x5d, 0x3a, 0x01, 0x91, 0x08,
    0x44, 0x22, 0xc4, 0xe2, 0x71, 0xe6, 0xd7, 0xd6, 0x26, 0x76, 0x54, 0x8a,
    0xd7, 0xfe, 0xfb, 0xf0, 0x31, 0xdf, 0xd2, 0xa4, 0x4d, 0xbc, 0x31, 0x36,
    0xf9, 0xde, 0x82, 0xf3, 0x19, 0x8c, 0x0e, 0xe7, 0xed, 0x44, 0x71, 0xad,
    0x10, 0xa2, 0x14, 0x79, 0x7d, 0xeb, 0xa8, 0xd5, 0xff, 0xea, 0xb2, 0x70,
    0x3e, 0xb6, 0xf8, 0x76, 0x7c, 0x7d, 0x27, 0x04, 0xe0, 0xa3, 0xbd, 0xc3,
    0x17, 0x9e, 0x79, 0x20, 0x46, 0xaf, 0xb5, 0x5b, 0xff, 0x05, 0x29, 0xbb,
    0xf6, 0x4a, 0x30, 0x33, 0xa8, 0xfe, 0xfc, 0x42, 0xdb, 0x19, 0x93, 0xad,
    0x52, 0x37, 0x39, 0xad, 0xdc, 0x79, 0x7f, 0xbb, 0xcd, 0x19, 0x98, 0xba,
    0x27, 0x9e, 0x5c, 0x39, 0x62, 0xff, 0xaf, 0x4e, 0x00, 0x16, 0x57, 0xe4,
    0xbb, 0xee, 0x77, 0x9f, 0x08, 0x56, 0x77, 0x34, 0x54, 0x6a, 0xe4, 0x0f,
    0x51, 0x7b, 0x2c, 0x24, 0xc5, 0xd9, 0x54, 0x2e, 0x00, 0x00, 0x00, 0x00,
    0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};


/*
 *  Constructs a configure as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
configure::configure( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    QImage img;
    img.loadFromData( img0_configure, sizeof( img0_configure ), "PNG" );
    image0 = img;
    img.loadFromData( img1_configure, sizeof( img1_configure ), "PNG" );
    image1 = img;
    img.loadFromData( img2_configure, sizeof( img2_configure ), "PNG" );
    image2 = img;
    img.loadFromData( img3_configure, sizeof( img3_configure ), "PNG" );
    image3 = img;
    img.loadFromData( img4_configure, sizeof( img4_configure ), "PNG" );
    image4 = img;
    img.loadFromData( img5_configure, sizeof( img5_configure ), "PNG" );
    image5 = img;
    img.loadFromData( img6_configure, sizeof( img6_configure ), "PNG" );
    image6 = img;
    img.loadFromData( img7_configure, sizeof( img7_configure ), "PNG" );
    image7 = img;
    img.loadFromData( img8_configure, sizeof( img8_configure ), "PNG" );
    image8 = img;
    img.loadFromData( img9_configure, sizeof( img9_configure ), "PNG" );
    image9 = img;
    if ( !name )
	setName( "configure" );
    setMinimumSize( QSize( 400, 200 ) );
    setMaximumSize( QSize( 32767, 32767 ) );
    setSizeGripEnabled( TRUE );
    setModal( FALSE );
    configureLayout = new QGridLayout( this, 1, 1, 7, 4, "configureLayout"); 

    layout143 = new QHBoxLayout( 0, 0, 6, "layout143"); 
    Horizontal_Spacing2 = new QSpacerItem( 460, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout143->addItem( Horizontal_Spacing2 );

    Ok = new QPushButton( this, "Ok" );
    Ok->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 15, 0, Ok->sizePolicy().hasHeightForWidth() ) );
    Ok->setMinimumSize( QSize( 110, 0 ) );
    Ok->setMaximumSize( QSize( 32767, 32767 ) );
    Ok->setAutoDefault( FALSE );
    Ok->setIconSet( QIconSet( image0 ) );
    layout143->addWidget( Ok );

    Apply = new QPushButton( this, "Apply" );
    Apply->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 15, 0, Apply->sizePolicy().hasHeightForWidth() ) );
    Apply->setMinimumSize( QSize( 110, 0 ) );
    Apply->setMaximumSize( QSize( 32767, 32767 ) );
    Apply->setAutoDefault( FALSE );
    Apply->setIconSet( QIconSet( image1 ) );
    layout143->addWidget( Apply );

    Cancel = new QPushButton( this, "Cancel" );
    Cancel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 15, 0, Cancel->sizePolicy().hasHeightForWidth() ) );
    Cancel->setMinimumSize( QSize( 110, 0 ) );
    Cancel->setMaximumSize( QSize( 32767, 32767 ) );
    Cancel->setAutoDefault( FALSE );
    Cancel->setIconSet( QIconSet( image2 ) );
    layout143->addWidget( Cancel );

    configureLayout->addMultiCellLayout( layout143, 1, 1, 0, 1 );

    optionList = new QListBox( this, "optionList" );
    optionList->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)7, 0, 0, optionList->sizePolicy().hasHeightForWidth() ) );
    optionList->setMinimumSize( QSize( 180, 200 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    optionList->setPalette( pal );
    optionList->setMargin( 0 );

    configureLayout->addWidget( optionList, 0, 0 );

    widgetList = new QWidgetStack( this, "widgetList" );
    widgetList->setMinimumSize( QSize( 100, 300 ) );
    widgetList->setFrameShape( QWidgetStack::Box );
    widgetList->setMargin( 0 );

    WStackPage = new QWidget( widgetList, "WStackPage" );
    WStackPageLayout = new QGridLayout( WStackPage, 1, 1, 11, 6, "WStackPageLayout"); 

    layout5 = new QHBoxLayout( 0, 0, 6, "layout5"); 
    spacer2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addItem( spacer2 );

    textLabel2_6 = new QLabel( WStackPage, "textLabel2_6" );
    textLabel2_6->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_font(  textLabel2_6->font() );
    textLabel2_6_font.setPointSize( 14 );
    textLabel2_6_font.setBold( TRUE );
    textLabel2_6->setFont( textLabel2_6_font ); 
    textLabel2_6->setFrameShape( QLabel::NoFrame );
    textLabel2_6->setFrameShadow( QLabel::Plain );
    textLabel2_6->setLineWidth( 0 );
    layout5->addWidget( textLabel2_6 );
    spacer3 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addItem( spacer3 );

    WStackPageLayout->addLayout( layout5, 0, 0 );

    frame4 = new QFrame( WStackPage, "frame4" );
    frame4->setMinimumSize( QSize( 0, 180 ) );
    frame4->setMaximumSize( QSize( 32767, 32767 ) );
    frame4->setFrameShape( QFrame::GroupBoxPanel );
    frame4->setFrameShadow( QFrame::Sunken );
    frame4Layout = new QGridLayout( frame4, 1, 1, 11, 6, "frame4Layout"); 

    layout42 = new QVBoxLayout( 0, 0, 6, "layout42"); 

    ShowOnline = new QCheckBox( frame4, "ShowOnline" );
    layout42->addWidget( ShowOnline );

    dockIcon = new QCheckBox( frame4, "dockIcon" );
    layout42->addWidget( dockIcon );

    frame4Layout->addLayout( layout42, 0, 0 );
    spacer42 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame4Layout->addItem( spacer42, 1, 0 );

    layout45 = new QHBoxLayout( 0, 0, 6, "layout45"); 

    textLabel1 = new QLabel( frame4, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 150, 0 ) );
    layout45->addWidget( textLabel1 );

    Browser = new QLineEdit( frame4, "Browser" );
    Browser->setMinimumSize( QSize( 130, 0 ) );
    Browser->setMaximumSize( QSize( 32767, 32767 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    Browser->setPalette( pal );
    layout45->addWidget( Browser );

    frame4Layout->addLayout( layout45, 2, 0 );
    spacer43 = new QSpacerItem( 20, 55, QSizePolicy::Minimum, QSizePolicy::Expanding );
    frame4Layout->addItem( spacer43, 6, 0 );

    authGroup = new QButtonGroup( frame4, "authGroup" );
    authGroup->setEnabled( FALSE );
    authGroup->setExclusive( FALSE );
    authGroup->setProperty( "selectedId", -1 );
    authGroup->setColumnLayout(0, Qt::Vertical );
    authGroup->layout()->setSpacing( 6 );
    authGroup->layout()->setMargin( 11 );
    authGroupLayout = new QGridLayout( authGroup->layout() );
    authGroupLayout->setAlignment( Qt::AlignTop );

    warnAuthButton = new QRadioButton( authGroup, "warnAuthButton" );

    authGroupLayout->addWidget( warnAuthButton, 1, 0 );

    askAuthButton = new QRadioButton( authGroup, "askAuthButton" );

    authGroupLayout->addWidget( askAuthButton, 2, 0 );

    noAuthButton = new QRadioButton( authGroup, "noAuthButton" );

    authGroupLayout->addWidget( noAuthButton, 0, 0 );

    frame4Layout->addWidget( authGroup, 4, 0 );

    messageGroup = new QButtonGroup( frame4, "messageGroup" );
    messageGroup->setEnabled( FALSE );
    messageGroup->setColumnLayout(0, Qt::Vertical );
    messageGroup->layout()->setSpacing( 6 );
    messageGroup->layout()->setMargin( 11 );
    messageGroupLayout = new QGridLayout( messageGroup->layout() );
    messageGroupLayout->setAlignment( Qt::AlignTop );

    reportButton = new QRadioButton( messageGroup, "reportButton" );

    messageGroupLayout->addWidget( reportButton, 0, 0 );

    emailButton = new QRadioButton( messageGroup, "emailButton" );

    messageGroupLayout->addWidget( emailButton, 1, 0 );

    frame4Layout->addWidget( messageGroup, 5, 0 );

    WStackPageLayout->addWidget( frame4, 1, 0 );
    widgetList->addWidget( WStackPage, 0 );

    WStackPage_2 = new QWidget( widgetList, "WStackPage_2" );
    WStackPageLayout_2 = new QGridLayout( WStackPage_2, 1, 1, 11, 6, "WStackPageLayout_2"); 

    groupBox1 = new QGroupBox( WStackPage_2, "groupBox1" );
    groupBox1->setMinimumSize( QSize( 0, 130 ) );
    groupBox1->setColumnLayout(0, Qt::Vertical );
    groupBox1->layout()->setSpacing( 2 );
    groupBox1->layout()->setMargin( 11 );
    groupBox1Layout = new QGridLayout( groupBox1->layout() );
    groupBox1Layout->setAlignment( Qt::AlignTop );

    layout67 = new QHBoxLayout( 0, 0, 6, "layout67"); 

    textLabel1_7 = new QLabel( groupBox1, "textLabel1_7" );
    textLabel1_7->setMinimumSize( QSize( 300, 0 ) );
    layout67->addWidget( textLabel1_7 );

    startStatusSwitch = new QComboBox( FALSE, groupBox1, "startStatusSwitch" );
    startStatusSwitch->setPaletteBackgroundColor( QColor( 230, 230, 230 ) );
    startStatusSwitch->setBackgroundOrigin( QComboBox::AncestorOrigin );
    startStatusSwitch->setFocusPolicy( QComboBox::ClickFocus );
    startStatusSwitch->setDuplicatesEnabled( TRUE );
    layout67->addWidget( startStatusSwitch );
    spacer56 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout67->addItem( spacer56 );

    groupBox1Layout->addLayout( layout67, 0, 0 );

    layout68 = new QHBoxLayout( 0, 0, 6, "layout68"); 

    textLabel1_7_2 = new QLabel( groupBox1, "textLabel1_7_2" );
    textLabel1_7_2->setMinimumSize( QSize( 200, 0 ) );
    layout68->addWidget( textLabel1_7_2 );

    maxTimeOut = new QSpinBox( groupBox1, "maxTimeOut" );
    maxTimeOut->setMaxValue( 65535 );
    maxTimeOut->setMinValue( 1 );
    layout68->addWidget( maxTimeOut );
    spacer57 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout68->addItem( spacer57 );

    groupBox1Layout->addLayout( layout68, 1, 0 );

    layout69 = new QVBoxLayout( 0, 0, 6, "layout69"); 

    AutoConnect = new QCheckBox( groupBox1, "AutoConnect" );
    layout69->addWidget( AutoConnect );

    Reconnect = new QCheckBox( groupBox1, "Reconnect" );
    Reconnect->setEnabled( TRUE );
    layout69->addWidget( Reconnect );

    ipShow = new QCheckBox( groupBox1, "ipShow" );
    layout69->addWidget( ipShow );

    groupBox1Layout->addLayout( layout69, 2, 0 );
    spacer58 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
    groupBox1Layout->addItem( spacer58, 3, 0 );

    WStackPageLayout_2->addWidget( groupBox1, 2, 0 );

    layout5_2 = new QHBoxLayout( 0, 0, 6, "layout5_2"); 
    spacer2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2->addItem( spacer2_2 );

    textLabel2_6_2 = new QLabel( WStackPage_2, "textLabel2_6_2" );
    textLabel2_6_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_font(  textLabel2_6_2->font() );
    textLabel2_6_2_font.setPointSize( 14 );
    textLabel2_6_2_font.setBold( TRUE );
    textLabel2_6_2->setFont( textLabel2_6_2_font ); 
    textLabel2_6_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2->setLineWidth( 0 );
    layout5_2->addWidget( textLabel2_6_2 );
    spacer3_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2->addItem( spacer3_2 );

    WStackPageLayout_2->addLayout( layout5_2, 0, 0 );

    groupBox2 = new QGroupBox( WStackPage_2, "groupBox2" );
    groupBox2->setMinimumSize( QSize( 0, 50 ) );
    groupBox2->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox2->setColumnLayout(0, Qt::Vertical );
    groupBox2->layout()->setSpacing( 6 );
    groupBox2->layout()->setMargin( 11 );
    groupBox2Layout = new QGridLayout( groupBox2->layout() );
    groupBox2Layout->setAlignment( Qt::AlignTop );

    layout65 = new QHBoxLayout( 0, 0, 6, "layout65"); 

    proxySwitch = new QCheckBox( groupBox2, "proxySwitch" );
    proxySwitch->setMinimumSize( QSize( 100, 0 ) );
    layout65->addWidget( proxySwitch );

    proxyName = new QLineEdit( groupBox2, "proxyName" );
    proxyName->setEnabled( FALSE );
    layout65->addWidget( proxyName );

    textLabel2_4 = new QLabel( groupBox2, "textLabel2_4" );
    layout65->addWidget( textLabel2_4 );

    layout63 = new QHBoxLayout( 0, 0, 6, "layout63"); 

    proxyPort = new QSpinBox( groupBox2, "proxyPort" );
    proxyPort->setEnabled( FALSE );
    proxyPort->setMaxValue( 65535 );
    proxyPort->setMinValue( 1 );
    proxyPort->setValue( 1080 );
    layout63->addWidget( proxyPort );

    proxySocksVersion = new QComboBox( FALSE, groupBox2, "proxySocksVersion" );
    proxySocksVersion->setEnabled( FALSE );
    layout63->addWidget( proxySocksVersion );
    layout65->addLayout( layout63 );

    groupBox2Layout->addLayout( layout65, 1, 0 );

    layout64 = new QHBoxLayout( 0, 0, 6, "layout64"); 

    textLabel1_2 = new QLabel( groupBox2, "textLabel1_2" );
    textLabel1_2->setMinimumSize( QSize( 100, 0 ) );
    textLabel1_2->setBackgroundOrigin( QLabel::WindowOrigin );
    layout64->addWidget( textLabel1_2 );

    serverName = new QLineEdit( groupBox2, "serverName" );
    layout64->addWidget( serverName );

    layout62 = new QHBoxLayout( 0, 0, 6, "layout62"); 

    textLabel2 = new QLabel( groupBox2, "textLabel2" );
    layout62->addWidget( textLabel2 );

    serverPort = new QSpinBox( groupBox2, "serverPort" );
    serverPort->setMaxValue( 65535 );
    serverPort->setMinValue( 1 );
    layout62->addWidget( serverPort );
    layout64->addLayout( layout62 );

    groupBox2Layout->addLayout( layout64, 0, 0 );

    layout66 = new QHBoxLayout( 0, 0, 6, "layout66"); 

    proxyAuthBox = new QGroupBox( groupBox2, "proxyAuthBox" );
    proxyAuthBox->setMinimumSize( QSize( 0, 100 ) );
    proxyAuthBox->setMaximumSize( QSize( 32767, 100 ) );
    proxyAuthBox->setBackgroundOrigin( QGroupBox::WindowOrigin );

    proxyUser = new QLineEdit( proxyAuthBox, "proxyUser" );
    proxyUser->setEnabled( FALSE );
    proxyUser->setGeometry( QRect( 105, 40, 175, 22 ) );

    textLabel3_3 = new QLabel( proxyAuthBox, "textLabel3_3" );
    textLabel3_3->setGeometry( QRect( 10, 66, 90, 24 ) );

    proxyAuthSwitch = new QCheckBox( proxyAuthBox, "proxyAuthSwitch" );
    proxyAuthSwitch->setGeometry( QRect( 10, 18, 145, 21 ) );

    proxyPassword = new QLineEdit( proxyAuthBox, "proxyPassword" );
    proxyPassword->setEnabled( FALSE );
    proxyPassword->setGeometry( QRect( 105, 67, 175, 22 ) );
    proxyPassword->setEchoMode( QLineEdit::Password );

    textLabel2_2 = new QLabel( proxyAuthBox, "textLabel2_2" );
    textLabel2_2->setGeometry( QRect( 10, 42, 90, 18 ) );
    layout66->addWidget( proxyAuthBox );

    groupBox2Layout->addLayout( layout66, 2, 0 );

    WStackPageLayout_2->addWidget( groupBox2, 1, 0 );
    widgetList->addWidget( WStackPage_2, 1 );

    WStackPage_3 = new QWidget( widgetList, "WStackPage_3" );
    WStackPageLayout_3 = new QGridLayout( WStackPage_3, 1, 1, 11, 6, "WStackPageLayout_3"); 

    layout5_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2"); 
    spacer2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2->addItem( spacer2_2_2 );

    textLabel2_6_2_2 = new QLabel( WStackPage_3, "textLabel2_6_2_2" );
    textLabel2_6_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_font(  textLabel2_6_2_2->font() );
    textLabel2_6_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_font.setBold( TRUE );
    textLabel2_6_2_2->setFont( textLabel2_6_2_2_font ); 
    textLabel2_6_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2->setLineWidth( 0 );
    layout5_2_2->addWidget( textLabel2_6_2_2 );
    spacer3_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2->addItem( spacer3_2_2 );

    WStackPageLayout_3->addLayout( layout5_2_2, 0, 0 );

    groupBox9 = new QGroupBox( WStackPage_3, "groupBox9" );
    groupBox9->setMinimumSize( QSize( 0, 0 ) );
    groupBox9->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox9->setColumnLayout(0, Qt::Vertical );
    groupBox9->layout()->setSpacing( 6 );
    groupBox9->layout()->setMargin( 11 );
    groupBox9Layout = new QGridLayout( groupBox9->layout() );
    groupBox9Layout->setAlignment( Qt::AlignTop );

    layout50 = new QHBoxLayout( 0, 0, 6, "layout50"); 

    layout48 = new QVBoxLayout( 0, 0, 6, "layout48"); 

    AutoRaise = new QCheckBox( groupBox9, "AutoRaise" );
    AutoRaise->setEnabled( TRUE );
    layout48->addWidget( AutoRaise );

    AutoPopUp = new QCheckBox( groupBox9, "AutoPopUp" );
    AutoPopUp->setEnabled( TRUE );
    layout48->addWidget( AutoPopUp );
    layout50->addLayout( layout48 );
    spacer44 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout50->addItem( spacer44 );

    layout49 = new QVBoxLayout( 0, 0, 6, "layout49"); 

    timeStamp = new QCheckBox( groupBox9, "timeStamp" );
    layout49->addWidget( timeStamp );

    tabbedChat = new QCheckBox( groupBox9, "tabbedChat" );
    layout49->addWidget( tabbedChat );
    layout50->addLayout( layout49 );

    groupBox9Layout->addLayout( layout50, 0, 0 );

    WStackPageLayout_3->addWidget( groupBox9, 1, 0 );

    acceptFile = new QGroupBox( WStackPage_3, "acceptFile" );
    acceptFile->setColumnLayout(0, Qt::Vertical );
    acceptFile->layout()->setSpacing( 6 );
    acceptFile->layout()->setMargin( 11 );
    acceptFileLayout = new QGridLayout( acceptFile->layout() );
    acceptFileLayout->setAlignment( Qt::AlignTop );

    layout51 = new QHBoxLayout( 0, 0, 6, "layout51"); 

    autoAccept = new QCheckBox( acceptFile, "autoAccept" );
    autoAccept->setMinimumSize( QSize( 0, 0 ) );
    layout51->addWidget( autoAccept );
    spacer45 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout51->addItem( spacer45 );

    acceptFileLayout->addLayout( layout51, 0, 0 );

    layout52 = new QHBoxLayout( 0, 0, 6, "layout52"); 

    textLabel1_10 = new QLabel( acceptFile, "textLabel1_10" );
    textLabel1_10->setMinimumSize( QSize( 180, 0 ) );
    layout52->addWidget( textLabel1_10 );

    fileReceivePath = new QLineEdit( acceptFile, "fileReceivePath" );
    layout52->addWidget( fileReceivePath );

    fileDir = new QPushButton( acceptFile, "fileDir" );
    fileDir->setPixmap( image3 );
    layout52->addWidget( fileDir );

    acceptFileLayout->addLayout( layout52, 1, 0 );

    layout53 = new QHBoxLayout( 0, 0, 6, "layout53"); 

    textLabel4_3 = new QLabel( acceptFile, "textLabel4_3" );
    textLabel4_3->setMinimumSize( QSize( 180, 0 ) );
    layout53->addWidget( textLabel4_3 );

    startPort = new QSpinBox( acceptFile, "startPort" );
    startPort->setMaxValue( 65536 );
    startPort->setMinValue( 1024 );
    layout53->addWidget( startPort );
    spacer46 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout53->addItem( spacer46 );

    acceptFileLayout->addLayout( layout53, 2, 0 );

    WStackPageLayout_3->addWidget( acceptFile, 2, 0 );
    spacer63_2 = new QSpacerItem( 20, 70, QSizePolicy::Minimum, QSizePolicy::Expanding );
    WStackPageLayout_3->addItem( spacer63_2, 3, 0 );
    widgetList->addWidget( WStackPage_3, 2 );

    WStackPage_4 = new QWidget( widgetList, "WStackPage_4" );
    WStackPageLayout_4 = new QGridLayout( WStackPage_4, 1, 1, 11, 6, "WStackPageLayout_4"); 

    layout5_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2"); 
    spacer2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2->addItem( spacer2_2_2_2 );

    textLabel2_6_2_2_2 = new QLabel( WStackPage_4, "textLabel2_6_2_2_2" );
    textLabel2_6_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_font(  textLabel2_6_2_2_2->font() );
    textLabel2_6_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2->setFont( textLabel2_6_2_2_2_font ); 
    textLabel2_6_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2->setLineWidth( 0 );
    layout5_2_2_2->addWidget( textLabel2_6_2_2_2 );
    spacer3_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2->addItem( spacer3_2_2_2 );

    WStackPageLayout_4->addLayout( layout5_2_2_2, 0, 0 );

    groupBox10 = new QGroupBox( WStackPage_4, "groupBox10" );
    groupBox10->setMinimumSize( QSize( 30, 0 ) );
    groupBox10->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox10->setColumnLayout(0, Qt::Vertical );
    groupBox10->layout()->setSpacing( 6 );
    groupBox10->layout()->setMargin( 11 );
    groupBox10Layout = new QGridLayout( groupBox10->layout() );
    groupBox10Layout->setAlignment( Qt::AlignTop );

    layout54 = new QVBoxLayout( 0, 0, 6, "layout54"); 

    roomTimeStamp = new QCheckBox( groupBox10, "roomTimeStamp" );
    layout54->addWidget( roomTimeStamp );

    autoRoomEnter = new QCheckBox( groupBox10, "autoRoomEnter" );
    layout54->addWidget( autoRoomEnter );

    groupBox10Layout->addLayout( layout54, 0, 0 );

    layout55 = new QHBoxLayout( 0, 0, 6, "layout55"); 

    autoRoomList = new QTextEdit( groupBox10, "autoRoomList" );
    autoRoomList->setMaximumSize( QSize( 300, 32767 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    autoRoomList->setPalette( pal );
    layout55->addWidget( autoRoomList );
    spacer48 = new QSpacerItem( 210, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout55->addItem( spacer48 );

    groupBox10Layout->addLayout( layout55, 1, 0 );

    WStackPageLayout_4->addWidget( groupBox10, 1, 0 );
    widgetList->addWidget( WStackPage_4, 3 );

    WStackPage_5 = new QWidget( widgetList, "WStackPage_5" );
    WStackPageLayout_5 = new QGridLayout( WStackPage_5, 1, 1, 11, 6, "WStackPageLayout_5"); 

    layout5_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2"); 
    spacer2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2->addItem( spacer2_2_2_2_2 );

    textLabel2_6_2_2_2_2 = new QLabel( WStackPage_5, "textLabel2_6_2_2_2_2" );
    textLabel2_6_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_font(  textLabel2_6_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2->setFont( textLabel2_6_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2->addWidget( textLabel2_6_2_2_2_2 );
    spacer3_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2->addItem( spacer3_2_2_2_2 );

    WStackPageLayout_5->addLayout( layout5_2_2_2_2, 0, 0 );

    groupBox11 = new QGroupBox( WStackPage_5, "groupBox11" );
    groupBox11->setMinimumSize( QSize( 0, 0 ) );
    groupBox11->setColumnLayout(0, Qt::Vertical );
    groupBox11->layout()->setSpacing( 6 );
    groupBox11->layout()->setMargin( 11 );
    groupBox11Layout = new QGridLayout( groupBox11->layout() );
    groupBox11Layout->setAlignment( Qt::AlignTop );

    AutoMsg = new QCheckBox( groupBox11, "AutoMsg" );

    groupBox11Layout->addWidget( AutoMsg, 0, 0 );

    layout56 = new QVBoxLayout( 0, 0, 6, "layout56"); 

    textLabel3_5 = new QLabel( groupBox11, "textLabel3_5" );
    textLabel3_5->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    QFont textLabel3_5_font(  textLabel3_5->font() );
    textLabel3_5_font.setBold( TRUE );
    textLabel3_5->setFont( textLabel3_5_font ); 
    layout56->addWidget( textLabel3_5 );

    BlackListEdit = new QLineEdit( groupBox11, "BlackListEdit" );
    layout56->addWidget( BlackListEdit );

    groupBox11Layout->addLayout( layout56, 1, 0 );

    layout57 = new QVBoxLayout( 0, 0, 6, "layout57"); 

    textLabel4_5 = new QLabel( groupBox11, "textLabel4_5" );
    textLabel4_5->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    QFont textLabel4_5_font(  textLabel4_5->font() );
    textLabel4_5_font.setBold( TRUE );
    textLabel4_5->setFont( textLabel4_5_font ); 
    layout57->addWidget( textLabel4_5 );

    NetFriendsEdit = new QLineEdit( groupBox11, "NetFriendsEdit" );
    layout57->addWidget( NetFriendsEdit );

    groupBox11Layout->addLayout( layout57, 2, 0 );

    layout58 = new QVBoxLayout( 0, 0, 6, "layout58"); 

    textLabel5 = new QLabel( groupBox11, "textLabel5" );
    textLabel5->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    QFont textLabel5_font(  textLabel5->font() );
    textLabel5_font.setBold( TRUE );
    textLabel5->setFont( textLabel5_font ); 
    layout58->addWidget( textLabel5 );

    BusyEdit = new QLineEdit( groupBox11, "BusyEdit" );
    layout58->addWidget( BusyEdit );

    groupBox11Layout->addLayout( layout58, 3, 0 );

    layout59 = new QVBoxLayout( 0, 0, 6, "layout59"); 

    textLabel1_9 = new QLabel( groupBox11, "textLabel1_9" );
    QFont textLabel1_9_font(  textLabel1_9->font() );
    textLabel1_9_font.setBold( TRUE );
    textLabel1_9->setFont( textLabel1_9_font ); 
    layout59->addWidget( textLabel1_9 );

    AwayEdit = new QLineEdit( groupBox11, "AwayEdit" );
    layout59->addWidget( AwayEdit );

    groupBox11Layout->addLayout( layout59, 4, 0 );

    layout60 = new QHBoxLayout( 0, 0, 6, "layout60"); 

    autoAwaySwitch = new QCheckBox( groupBox11, "autoAwaySwitch" );
    layout60->addWidget( autoAwaySwitch );

    awayMinutes = new QSpinBox( groupBox11, "awayMinutes" );
    awayMinutes->setMaxValue( 3600 );
    awayMinutes->setMinValue( 1 );
    layout60->addWidget( awayMinutes );

    textLabel1_12 = new QLabel( groupBox11, "textLabel1_12" );
    layout60->addWidget( textLabel1_12 );
    spacer50 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout60->addItem( spacer50 );

    groupBox11Layout->addLayout( layout60, 5, 0 );

    layout61 = new QHBoxLayout( 0, 0, 6, "layout61"); 

    backAutoAwaySwitch = new QCheckBox( groupBox11, "backAutoAwaySwitch" );
    layout61->addWidget( backAutoAwaySwitch );
    spacer51 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout61->addItem( spacer51 );

    groupBox11Layout->addLayout( layout61, 6, 0 );

    WStackPageLayout_5->addWidget( groupBox11, 1, 0 );
    spacer64 = new QSpacerItem( 20, 150, QSizePolicy::Minimum, QSizePolicy::Expanding );
    WStackPageLayout_5->addItem( spacer64, 2, 0 );
    widgetList->addWidget( WStackPage_5, 4 );

    WStackPage_6 = new QWidget( widgetList, "WStackPage_6" );
    WStackPageLayout_6 = new QGridLayout( WStackPage_6, 1, 1, 11, 1, "WStackPageLayout_6"); 

    layout5_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2"); 
    spacer2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2->addItem( spacer2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2 = new QLabel( WStackPage_6, "textLabel2_6_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2 );
    spacer3_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2->addItem( spacer3_2_2_2_2_2 );

    WStackPageLayout_6->addLayout( layout5_2_2_2_2_2, 0, 0 );

    groupBox13 = new QGroupBox( WStackPage_6, "groupBox13" );
    groupBox13->setMinimumSize( QSize( 0, 0 ) );
    groupBox13->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox13->setColumnLayout(0, Qt::Vertical );
    groupBox13->layout()->setSpacing( 2 );
    groupBox13->layout()->setMargin( 11 );
    groupBox13Layout = new QGridLayout( groupBox13->layout() );
    groupBox13Layout->setAlignment( Qt::AlignTop );

    layout13 = new QHBoxLayout( 0, 0, 6, "layout13"); 

    selectFontButton = new QCheckBox( groupBox13, "selectFontButton" );
    layout13->addWidget( selectFontButton );
    spacer23_2 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout13->addItem( spacer23_2 );

    groupBox13Layout->addLayout( layout13, 0, 0 );

    layout14 = new QHBoxLayout( 0, 0, 6, "layout14"); 

    textLabel1_11 = new QLabel( groupBox13, "textLabel1_11" );
    textLabel1_11->setMinimumSize( QSize( 60, 0 ) );
    layout14->addWidget( textLabel1_11 );

    fontProperty = new QLineEdit( groupBox13, "fontProperty" );
    fontProperty->setReadOnly( TRUE );
    layout14->addWidget( fontProperty );

    globalFontButton = new QPushButton( groupBox13, "globalFontButton" );
    globalFontButton->setAutoDefault( FALSE );
    globalFontButton->setIconSet( QIconSet( image4 ) );
    layout14->addWidget( globalFontButton );

    defaultFontButton = new QPushButton( groupBox13, "defaultFontButton" );
    defaultFontButton->setMinimumSize( QSize( 100, 0 ) );
    layout14->addWidget( defaultFontButton );

    groupBox13Layout->addLayout( layout14, 1, 0 );

    WStackPageLayout_6->addWidget( groupBox13, 1, 0 );

    groupBox12 = new QGroupBox( WStackPage_6, "groupBox12" );
    groupBox12->setMinimumSize( QSize( 0, 216 ) );
    groupBox12->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox12->setColumnLayout(0, Qt::Vertical );
    groupBox12->layout()->setSpacing( 5 );
    groupBox12->layout()->setMargin( 11 );
    groupBox12Layout = new QGridLayout( groupBox12->layout() );
    groupBox12Layout->setAlignment( Qt::AlignTop );

    layout17 = new QHBoxLayout( 0, 0, 6, "layout17"); 
    spacer24 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout17->addItem( spacer24 );

    Default = new QPushButton( groupBox12, "Default" );
    Default->setMinimumSize( QSize( 100, 0 ) );
    Default->setAutoDefault( FALSE );
    layout17->addWidget( Default );

    groupBox12Layout->addLayout( layout17, 2, 0 );

    groupBox15 = new QGroupBox( groupBox12, "groupBox15" );
    groupBox15->setMinimumSize( QSize( 0, 115 ) );
    groupBox15->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox15->setColumnLayout(0, Qt::Vertical );
    groupBox15->layout()->setSpacing( 6 );
    groupBox15->layout()->setMargin( 11 );
    groupBox15Layout = new QGridLayout( groupBox15->layout() );
    groupBox15Layout->setAlignment( Qt::AlignTop );

    layout76 = new QHBoxLayout( 0, 0, 6, "layout76"); 

    layout75 = new QVBoxLayout( 0, 0, 6, "layout75"); 

    layout72 = new QHBoxLayout( 0, 0, 6, "layout72"); 

    textLabel1_8 = new QLabel( groupBox15, "textLabel1_8" );
    layout72->addWidget( textLabel1_8 );

    SelFontUp = new QPushButton( groupBox15, "SelFontUp" );
    SelFontUp->setMinimumSize( QSize( 25, 25 ) );
    SelFontUp->setMaximumSize( QSize( 25, 25 ) );
    SelFontUp->setAutoDefault( FALSE );
    SelFontUp->setIconSet( QIconSet( image4 ) );
    layout72->addWidget( SelFontUp );
    layout75->addLayout( layout72 );

    layout73_2 = new QHBoxLayout( 0, 0, 6, "layout73_2"); 

    textLabel1_4_4 = new QLabel( groupBox15, "textLabel1_4_4" );
    layout73_2->addWidget( textLabel1_4_4 );

    netfriendColorButton = new QPushButton( groupBox15, "netfriendColorButton" );
    netfriendColorButton->setMinimumSize( QSize( 25, 25 ) );
    netfriendColorButton->setMaximumSize( QSize( 25, 25 ) );
    netfriendColorButton->setAutoDefault( FALSE );
    netfriendColorButton->setIconSet( QIconSet( image5 ) );
    layout73_2->addWidget( netfriendColorButton );
    layout75->addLayout( layout73_2 );

    layout74 = new QHBoxLayout( 0, 0, 6, "layout74"); 

    textLabel3_2_5 = new QLabel( groupBox15, "textLabel3_2_5" );
    layout74->addWidget( textLabel3_2_5 );

    myselfColor = new QPushButton( groupBox15, "myselfColor" );
    myselfColor->setMinimumSize( QSize( 25, 25 ) );
    myselfColor->setMaximumSize( QSize( 25, 25 ) );
    myselfColor->setAutoDefault( FALSE );
    myselfColor->setIconSet( QIconSet( image5 ) );
    layout74->addWidget( myselfColor );
    layout75->addLayout( layout74 );
    layout76->addLayout( layout75 );

    chatPreview = new QTextEdit( groupBox15, "chatPreview" );
    chatPreview->setMinimumSize( QSize( 0, 80 ) );
    chatPreview->setMaximumSize( QSize( 32767, 32767 ) );
    chatPreview->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    chatPreview->setPalette( pal );
    chatPreview->setFocusPolicy( QTextEdit::NoFocus );
    chatPreview->setTextFormat( QTextEdit::RichText );
    chatPreview->setReadOnly( TRUE );
    layout76->addWidget( chatPreview );

    groupBox15Layout->addLayout( layout76, 0, 0 );

    groupBox12Layout->addWidget( groupBox15, 0, 0 );

    layout82 = new QHBoxLayout( 0, 0, 6, "layout82"); 

    MessageUpLabel = new QLabel( groupBox12, "MessageUpLabel" );
    MessageUpLabel->setMinimumSize( QSize( 60, 0 ) );
    layout82->addWidget( MessageUpLabel );

    serviceMessagePreview = new QLineEdit( groupBox12, "serviceMessagePreview" );
    layout82->addWidget( serviceMessagePreview );

    serviceMessageColor = new QPushButton( groupBox12, "serviceMessageColor" );
    serviceMessageColor->setMinimumSize( QSize( 25, 25 ) );
    serviceMessageColor->setMaximumSize( QSize( 25, 25 ) );
    serviceMessageColor->setAutoDefault( FALSE );
    serviceMessageColor->setIconSet( QIconSet( image5 ) );
    layout82->addWidget( serviceMessageColor );

    groupBox12Layout->addLayout( layout82, 1, 0 );

    WStackPageLayout_6->addWidget( groupBox12, 2, 0 );
    spacer62 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
    WStackPageLayout_6->addItem( spacer62, 4, 0 );

    groupBox11_2 = new QGroupBox( WStackPage_6, "groupBox11_2" );
    groupBox11_2->setColumnLayout(0, Qt::Vertical );
    groupBox11_2->layout()->setSpacing( 3 );
    groupBox11_2->layout()->setMargin( 11 );
    groupBox11_2Layout = new QGridLayout( groupBox11_2->layout() );
    groupBox11_2Layout->setAlignment( Qt::AlignTop );

    layout18 = new QHBoxLayout( 0, 0, 6, "layout18"); 

    contactFontSwitch = new QCheckBox( groupBox11_2, "contactFontSwitch" );
    contactFontSwitch->setMinimumSize( QSize( 90, 0 ) );
    layout18->addWidget( contactFontSwitch );

    textLabel1_8_2 = new QLabel( groupBox11_2, "textLabel1_8_2" );
    textLabel1_8_2->setMinimumSize( QSize( 60, 0 ) );
    layout18->addWidget( textLabel1_8_2 );

    contactFontProperty = new QLineEdit( groupBox11_2, "contactFontProperty" );
    contactFontProperty->setReadOnly( TRUE );
    layout18->addWidget( contactFontProperty );

    contactSelFont = new QPushButton( groupBox11_2, "contactSelFont" );
    contactSelFont->setAutoDefault( FALSE );
    contactSelFont->setIconSet( QIconSet( image4 ) );
    layout18->addWidget( contactSelFont );

    groupBox11_2Layout->addLayout( layout18, 0, 0 );

    layout19 = new QHBoxLayout( 0, 0, 6, "layout19"); 

    MessageUpLabel_2 = new QLabel( groupBox11_2, "MessageUpLabel_2" );
    MessageUpLabel_2->setMinimumSize( QSize( 156, 0 ) );
    layout19->addWidget( MessageUpLabel_2 );

    groupColor = new QLabel( groupBox11_2, "groupColor" );
    groupColor->setMinimumSize( QSize( 100, 20 ) );
    groupColor->setMaximumSize( QSize( 100, 20 ) );
    groupColor->setPaletteBackgroundColor( QColor( 3, 118, 231 ) );
    groupColor->setFrameShape( QLabel::LineEditPanel );
    groupColor->setFrameShadow( QLabel::Plain );
    groupColor->setLineWidth( 2 );
    groupColor->setScaledContents( TRUE );
    layout19->addWidget( groupColor );

    groupNameForeColor = new QPushButton( groupBox11_2, "groupNameForeColor" );
    groupNameForeColor->setAutoDefault( FALSE );
    groupNameForeColor->setIconSet( QIconSet( image5 ) );
    layout19->addWidget( groupNameForeColor );
    spacer25 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout19->addItem( spacer25 );

    groupBox11_2Layout->addLayout( layout19, 1, 0 );

    layout76_2 = new QHBoxLayout( 0, 0, 6, "layout76_2"); 

    layout20 = new QHBoxLayout( 0, 0, 6, "layout20"); 

    MessageUpLabel_3 = new QLabel( groupBox11_2, "MessageUpLabel_3" );
    MessageUpLabel_3->setMinimumSize( QSize( 156, 0 ) );
    layout20->addWidget( MessageUpLabel_3 );

    userColor = new QLabel( groupBox11_2, "userColor" );
    userColor->setMinimumSize( QSize( 100, 20 ) );
    userColor->setMaximumSize( QSize( 100, 20 ) );
    userColor->setPaletteBackgroundColor( QColor( 92, 92, 92 ) );
    userColor->setFrameShape( QLabel::LineEditPanel );
    userColor->setFrameShadow( QLabel::Plain );
    userColor->setLineWidth( 2 );
    userColor->setScaledContents( TRUE );
    layout20->addWidget( userColor );

    contactForeColor = new QPushButton( groupBox11_2, "contactForeColor" );
    contactForeColor->setAutoDefault( FALSE );
    contactForeColor->setIconSet( QIconSet( image5 ) );
    layout20->addWidget( contactForeColor );
    spacer26 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout20->addItem( spacer26 );
    layout76_2->addLayout( layout20 );

    defaultContact = new QPushButton( groupBox11_2, "defaultContact" );
    defaultContact->setMinimumSize( QSize( 100, 0 ) );
    defaultContact->setAutoDefault( FALSE );
    layout76_2->addWidget( defaultContact );

    groupBox11_2Layout->addLayout( layout76_2, 2, 0 );

    WStackPageLayout_6->addWidget( groupBox11_2, 3, 0 );
    widgetList->addWidget( WStackPage_6, 5 );

    WStackPage_7 = new QWidget( widgetList, "WStackPage_7" );
    WStackPageLayout_7 = new QGridLayout( WStackPage_7, 1, 1, 11, 6, "WStackPageLayout_7"); 

    layout5_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2 = new QLabel( WStackPage_7, "textLabel2_6_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2 );

    WStackPageLayout_7->addLayout( layout5_2_2_2_2_2_2, 0, 0 );

    frame10 = new QFrame( WStackPage_7, "frame10" );
    frame10->setMinimumSize( QSize( 0, 0 ) );
    frame10->setMaximumSize( QSize( 32767, 32767 ) );
    frame10->setFrameShape( QFrame::GroupBoxPanel );
    frame10->setFrameShadow( QFrame::Sunken );
    frame10Layout = new QGridLayout( frame10, 1, 1, 11, 6, "frame10Layout"); 

    layout21 = new QVBoxLayout( 0, 0, 6, "layout21"); 

    beepSwitch = new QCheckBox( frame10, "beepSwitch" );
    layout21->addWidget( beepSwitch );

    soundOnceSwitch = new QCheckBox( frame10, "soundOnceSwitch" );
    layout21->addWidget( soundOnceSwitch );

    soundSwitch = new QCheckBox( frame10, "soundSwitch" );
    soundSwitch->setEnabled( TRUE );
    layout21->addWidget( soundSwitch );

    frame10Layout->addLayout( layout21, 0, 0 );

    layout23 = new QVBoxLayout( 0, 0, 6, "layout23"); 
    spacer27 = new QSpacerItem( 20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout23->addItem( spacer27 );

    layout22 = new QHBoxLayout( 0, 0, 6, "layout22"); 

    textLabel1_5 = new QLabel( frame10, "textLabel1_5" );
    layout22->addWidget( textLabel1_5 );

    playCommand = new QLineEdit( frame10, "playCommand" );
    layout22->addWidget( playCommand );
    layout23->addLayout( layout22 );

    frame10Layout->addLayout( layout23, 0, 1 );

    WStackPageLayout_7->addWidget( frame10, 1, 0 );

    soundGroup = new QGroupBox( WStackPage_7, "soundGroup" );
    soundGroup->setColumnLayout(0, Qt::Vertical );
    soundGroup->layout()->setSpacing( 4 );
    soundGroup->layout()->setMargin( 11 );
    soundGroupLayout = new QGridLayout( soundGroup->layout() );
    soundGroupLayout->setAlignment( Qt::AlignTop );

    layout24 = new QHBoxLayout( 0, 0, 6, "layout24"); 

    inMessageSwitch = new QCheckBox( soundGroup, "inMessageSwitch" );
    layout24->addWidget( inMessageSwitch );
    spacer28 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout24->addItem( spacer28 );

    soundGroupLayout->addLayout( layout24, 0, 0 );

    layout25 = new QHBoxLayout( 0, 0, 6, "layout25"); 

    inMessageWav = new QLineEdit( soundGroup, "inMessageWav" );
    layout25->addWidget( inMessageWav );

    fileOpen1 = new QPushButton( soundGroup, "fileOpen1" );
    fileOpen1->setPixmap( image3 );
    layout25->addWidget( fileOpen1 );

    playDemo1 = new QPushButton( soundGroup, "playDemo1" );
    playDemo1->setPixmap( image6 );
    playDemo1->setAutoDefault( FALSE );
    layout25->addWidget( playDemo1 );

    soundGroupLayout->addLayout( layout25, 1, 0 );

    layout26 = new QHBoxLayout( 0, 0, 6, "layout26"); 

    outMessageSwitch = new QCheckBox( soundGroup, "outMessageSwitch" );
    layout26->addWidget( outMessageSwitch );
    spacer29 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout26->addItem( spacer29 );

    soundGroupLayout->addLayout( layout26, 2, 0 );

    layout27 = new QHBoxLayout( 0, 0, 6, "layout27"); 

    outMessageWav = new QLineEdit( soundGroup, "outMessageWav" );
    layout27->addWidget( outMessageWav );

    fileOpen2 = new QPushButton( soundGroup, "fileOpen2" );
    fileOpen2->setPixmap( image3 );
    layout27->addWidget( fileOpen2 );

    playDemo2 = new QPushButton( soundGroup, "playDemo2" );
    playDemo2->setPixmap( image6 );
    playDemo2->setAutoDefault( FALSE );
    layout27->addWidget( playDemo2 );

    soundGroupLayout->addLayout( layout27, 3, 0 );

    layout28 = new QHBoxLayout( 0, 0, 6, "layout28"); 

    onlineMessageSwitch = new QCheckBox( soundGroup, "onlineMessageSwitch" );
    layout28->addWidget( onlineMessageSwitch );
    spacer30 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout28->addItem( spacer30 );

    soundGroupLayout->addLayout( layout28, 4, 0 );

    layout29 = new QHBoxLayout( 0, 0, 6, "layout29"); 

    onlineMessageWav = new QLineEdit( soundGroup, "onlineMessageWav" );
    layout29->addWidget( onlineMessageWav );

    fileOpen3 = new QPushButton( soundGroup, "fileOpen3" );
    fileOpen3->setPixmap( image3 );
    layout29->addWidget( fileOpen3 );

    playDemo3 = new QPushButton( soundGroup, "playDemo3" );
    playDemo3->setPixmap( image6 );
    playDemo3->setDefault( FALSE );
    layout29->addWidget( playDemo3 );

    soundGroupLayout->addLayout( layout29, 5, 0 );

    layout30 = new QHBoxLayout( 0, 0, 6, "layout30"); 

    offlineMessageSwitch = new QCheckBox( soundGroup, "offlineMessageSwitch" );
    layout30->addWidget( offlineMessageSwitch );
    spacer31 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout30->addItem( spacer31 );

    soundGroupLayout->addLayout( layout30, 6, 0 );

    layout31 = new QHBoxLayout( 0, 0, 6, "layout31"); 

    offlineMessageWav = new QLineEdit( soundGroup, "offlineMessageWav" );
    layout31->addWidget( offlineMessageWav );

    fileOpen4 = new QPushButton( soundGroup, "fileOpen4" );
    fileOpen4->setPixmap( image3 );
    layout31->addWidget( fileOpen4 );

    playDemo4 = new QPushButton( soundGroup, "playDemo4" );
    playDemo4->setPixmap( image6 );
    playDemo4->setAutoDefault( FALSE );
    layout31->addWidget( playDemo4 );

    soundGroupLayout->addLayout( layout31, 7, 0 );

    layout32 = new QHBoxLayout( 0, 0, 6, "layout32"); 

    specialFriendSwitch = new QCheckBox( soundGroup, "specialFriendSwitch" );
    layout32->addWidget( specialFriendSwitch );
    spacer32 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout32->addItem( spacer32 );

    soundGroupLayout->addLayout( layout32, 8, 0 );

    layout33 = new QHBoxLayout( 0, 0, 6, "layout33"); 

    specialFriendWav = new QLineEdit( soundGroup, "specialFriendWav" );
    layout33->addWidget( specialFriendWav );

    fileOpen5 = new QPushButton( soundGroup, "fileOpen5" );
    fileOpen5->setPixmap( image3 );
    layout33->addWidget( fileOpen5 );

    playDemo5 = new QPushButton( soundGroup, "playDemo5" );
    playDemo5->setPixmap( image6 );
    playDemo5->setAutoDefault( FALSE );
    layout33->addWidget( playDemo5 );

    soundGroupLayout->addLayout( layout33, 9, 0 );

    WStackPageLayout_7->addWidget( soundGroup, 2, 0 );
    spacer38 = new QSpacerItem( 20, 31, QSizePolicy::Minimum, QSizePolicy::Expanding );
    WStackPageLayout_7->addItem( spacer38, 3, 0 );
    widgetList->addWidget( WStackPage_7, 6 );

    WStackPage_8 = new QWidget( widgetList, "WStackPage_8" );
    WStackPageLayout_8 = new QGridLayout( WStackPage_8, 1, 1, 11, 6, "WStackPageLayout_8"); 

    layout5_2_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2_2 = new QLabel( WStackPage_8, "textLabel2_6_2_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2_2 );

    WStackPageLayout_8->addLayout( layout5_2_2_2_2_2_2_2, 0, 0 );

    frame11 = new QFrame( WStackPage_8, "frame11" );
    frame11->setMinimumSize( QSize( 0, 50 ) );
    frame11->setFrameShape( QFrame::GroupBoxPanel );
    frame11->setFrameShadow( QFrame::Sunken );
    frame11Layout = new QGridLayout( frame11, 1, 1, 11, 6, "frame11Layout"); 

    layout34 = new QVBoxLayout( 0, 0, 6, "layout34"); 

    textLabel1_4 = new QLabel( frame11, "textLabel1_4" );
    layout34->addWidget( textLabel1_4 );

    specialList = new QListBox( frame11, "specialList" );
    specialList->setMinimumSize( QSize( 0, 0 ) );
    specialList->setMaximumSize( QSize( 200, 32767 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    specialList->setPalette( pal );
    layout34->addWidget( specialList );

    frame11Layout->addLayout( layout34, 0, 0 );

    layout40 = new QVBoxLayout( 0, 0, 6, "layout40"); 

    layout35 = new QVBoxLayout( 0, 0, 6, "layout35"); 

    textLabel1_6 = new QLabel( frame11, "textLabel1_6" );
    layout35->addWidget( textLabel1_6 );

    specialEdit = new QLineEdit( frame11, "specialEdit" );
    layout35->addWidget( specialEdit );
    layout40->addLayout( layout35 );

    layout39 = new QHBoxLayout( 0, 0, 6, "layout39"); 

    removeSpecial = new QPushButton( frame11, "removeSpecial" );
    removeSpecial->setMinimumSize( QSize( 115, 0 ) );
    removeSpecial->setMaximumSize( QSize( 100, 32767 ) );
    removeSpecial->setBackgroundOrigin( QPushButton::WidgetOrigin );
    removeSpecial->setAutoDefault( FALSE );
    removeSpecial->setIconSet( QIconSet( image7 ) );
    layout39->addWidget( removeSpecial );

    addSpecial = new QPushButton( frame11, "addSpecial" );
    addSpecial->setMinimumSize( QSize( 115, 0 ) );
    addSpecial->setMaximumSize( QSize( 100, 32767 ) );
    addSpecial->setAutoDefault( FALSE );
    addSpecial->setIconSet( QIconSet( image8 ) );
    layout39->addWidget( addSpecial );
    spacer36 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout39->addItem( spacer36 );
    layout40->addLayout( layout39 );

    specialNotifySwitch = new QCheckBox( frame11, "specialNotifySwitch" );
    layout40->addWidget( specialNotifySwitch );
    spacer34 = new QSpacerItem( 20, 111, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout40->addItem( spacer34 );

    frame11Layout->addLayout( layout40, 0, 1 );

    WStackPageLayout_8->addWidget( frame11, 1, 0 );
    widgetList->addWidget( WStackPage_8, 7 );

    WStackPage_9 = new QWidget( widgetList, "WStackPage_9" );
    WStackPageLayout_9 = new QGridLayout( WStackPage_9, 1, 1, 11, 6, "WStackPageLayout_9"); 

    layout5_2_2_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2_2_2 = new QLabel( WStackPage_9, "textLabel2_6_2_2_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2_2_2 );

    WStackPageLayout_9->addLayout( layout5_2_2_2_2_2_2_2_2, 0, 0 );

    frame12 = new QFrame( WStackPage_9, "frame12" );
    frame12->setFrameShape( QFrame::GroupBoxPanel );
    frame12->setFrameShadow( QFrame::Sunken );
    frame12Layout = new QGridLayout( frame12, 1, 1, 11, 6, "frame12Layout"); 

    layout41 = new QVBoxLayout( 0, 0, 6, "layout41"); 

    LogProto = new QCheckBox( frame12, "LogProto" );
    layout41->addWidget( LogProto );

    Log = new QCheckBox( frame12, "Log" );
    layout41->addWidget( Log );

    LogRoom = new QCheckBox( frame12, "LogRoom" );
    layout41->addWidget( LogRoom );

    SysLog = new QCheckBox( frame12, "SysLog" );
    layout41->addWidget( SysLog );

    frame12Layout->addLayout( layout41, 0, 0 );
    spacer37 = new QSpacerItem( 20, 80, QSizePolicy::Minimum, QSizePolicy::Expanding );
    frame12Layout->addItem( spacer37, 1, 0 );

    WStackPageLayout_9->addWidget( frame12, 1, 0 );
    widgetList->addWidget( WStackPage_9, 8 );

    WStackPage_10 = new QWidget( widgetList, "WStackPage_10" );
    WStackPageLayout_10 = new QGridLayout( WStackPage_10, 1, 1, 11, 6, "WStackPageLayout_10"); 

    layout5_2_2_2_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2_2_2_2 = new QLabel( WStackPage_10, "textLabel2_6_2_2_2_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2_2_2_2 );

    WStackPageLayout_10->addLayout( layout5_2_2_2_2_2_2_2_2_2, 0, 0 );

    groupBox13_2 = new QGroupBox( WStackPage_10, "groupBox13_2" );
    groupBox13_2->setMinimumSize( QSize( 100, 0 ) );
    groupBox13_2->setColumnLayout(0, Qt::Vertical );
    groupBox13_2->layout()->setSpacing( 6 );
    groupBox13_2->layout()->setMargin( 11 );
    groupBox13_2Layout = new QGridLayout( groupBox13_2->layout() );
    groupBox13_2Layout->setAlignment( Qt::AlignTop );

    pluginsLoadedList = new QListView( groupBox13_2, "pluginsLoadedList" );
    pluginsLoadedList->addColumn( ( "File" ) );
    pluginsLoadedList->addColumn( ( "Nome" ) );
    pluginsLoadedList->addColumn( ( "Descrizione" ) );
    pluginsLoadedList->addColumn( ( "KDE" ) );
    pluginsLoadedList->addColumn( ( "Attivo" ) );
    pluginsLoadedList->setMinimumSize( QSize( 100, 0 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    pluginsLoadedList->setPalette( pal );
    pluginsLoadedList->setResizeMode( QListView::AllColumns );

    groupBox13_2Layout->addWidget( pluginsLoadedList, 0, 0 );

    layout13_2 = new QHBoxLayout( 0, 0, 6, "layout13_2"); 
    spacer23 = new QSpacerItem( 220, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout13_2->addItem( spacer23 );

    pluginUnload = new QPushButton( groupBox13_2, "pluginUnload" );
    pluginUnload->setMinimumSize( QSize( 100, 0 ) );
    pluginUnload->setMaximumSize( QSize( 100, 32767 ) );
    layout13_2->addWidget( pluginUnload );

    groupBox13_2Layout->addLayout( layout13_2, 1, 0 );

    WStackPageLayout_10->addWidget( groupBox13_2, 1, 0 );

    groupBox12_2 = new QGroupBox( WStackPage_10, "groupBox12_2" );
    groupBox12_2->setMinimumSize( QSize( 100, 0 ) );
    groupBox12_2->setColumnLayout(0, Qt::Vertical );
    groupBox12_2->layout()->setSpacing( 6 );
    groupBox12_2->layout()->setMargin( 11 );
    groupBox12_2Layout = new QGridLayout( groupBox12_2->layout() );
    groupBox12_2Layout->setAlignment( Qt::AlignTop );

    pluginsAvailableList = new QListView( groupBox12_2, "pluginsAvailableList" );
    pluginsAvailableList->addColumn( ( "Column 1" ) );
    pluginsAvailableList->setMinimumSize( QSize( 100, 70 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    pluginsAvailableList->setPalette( pal );

    groupBox12_2Layout->addMultiCellWidget( pluginsAvailableList, 0, 0, 0, 1 );

    pluginLoad = new QPushButton( groupBox12_2, "pluginLoad" );
    pluginLoad->setMinimumSize( QSize( 100, 0 ) );
    pluginLoad->setMaximumSize( QSize( 100, 32767 ) );

    groupBox12_2Layout->addWidget( pluginLoad, 1, 1 );

    frame23 = new QFrame( groupBox12_2, "frame23" );
    frame23->setMinimumSize( QSize( 0, 30 ) );
    frame23->setFrameShape( QFrame::NoFrame );
    frame23->setFrameShadow( QFrame::Plain );
    frame23->setLineWidth( 0 );
    frame23Layout = new QGridLayout( frame23, 1, 1, 0, 6, "frame23Layout"); 

    textLabel1_3 = new QLabel( frame23, "textLabel1_3" );
    textLabel1_3->setIndent( -2 );

    frame23Layout->addWidget( textLabel1_3, 0, 0 );

    groupBox12_2Layout->addWidget( frame23, 1, 0 );

    WStackPageLayout_10->addWidget( groupBox12_2, 2, 0 );
    widgetList->addWidget( WStackPage_10, 9 );

    WStackPage_11 = new QWidget( widgetList, "WStackPage_11" );
    WStackPageLayout_11 = new QGridLayout( WStackPage_11, 1, 1, 11, 6, "WStackPageLayout_11"); 

    layout5_2_2_2_2_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2_2_2_2_2 = new QLabel( WStackPage_11, "textLabel2_6_2_2_2_2_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2_2_2_2_2 );

    WStackPageLayout_11->addLayout( layout5_2_2_2_2_2_2_2_2_2_2, 0, 0 );

    groupBox27 = new QGroupBox( WStackPage_11, "groupBox27" );
    groupBox27->setMinimumSize( QSize( 0, 0 ) );
    groupBox27->setMaximumSize( QSize( 32767, 32767 ) );
    groupBox27->setColumnLayout(0, Qt::Vertical );
    groupBox27->layout()->setSpacing( 6 );
    groupBox27->layout()->setMargin( 11 );
    groupBox27Layout = new QGridLayout( groupBox27->layout() );
    groupBox27Layout->setAlignment( Qt::AlignTop );

    layout142 = new QVBoxLayout( 0, 0, 6, "layout142"); 

    activateStyle = new QCheckBox( groupBox27, "activateStyle" );
    layout142->addWidget( activateStyle );

    layout141 = new QHBoxLayout( 0, 0, 6, "layout141"); 

    textLabel1_2_2 = new QLabel( groupBox27, "textLabel1_2_2" );
    textLabel1_2_2->setMinimumSize( QSize( 80, 0 ) );
    textLabel1_2_2->setMaximumSize( QSize( 80, 32767 ) );
    layout141->addWidget( textLabel1_2_2 );

    styleCombo = new QComboBox( FALSE, groupBox27, "styleCombo" );
    styleCombo->setEnabled( FALSE );
    styleCombo->setMinimumSize( QSize( 200, 0 ) );
    layout141->addWidget( styleCombo );
    layout142->addLayout( layout141 );

    groupBox27Layout->addLayout( layout142, 0, 0 );

    WStackPageLayout_11->addWidget( groupBox27, 1, 0 );
    spacer66 = new QSpacerItem( 20, 370, QSizePolicy::Minimum, QSizePolicy::Expanding );
    WStackPageLayout_11->addItem( spacer66, 2, 0 );
    widgetList->addWidget( WStackPage_11, 10 );

    WStackPage_12 = new QWidget( widgetList, "WStackPage_12" );
    WStackPageLayout_12 = new QGridLayout( WStackPage_12, 1, 1, 11, 6, "WStackPageLayout_12"); 

    layout5_2_2_2_2_2_2_2_2_2_2_2 = new QHBoxLayout( 0, 0, 6, "layout5_2_2_2_2_2_2_2_2_2_2_2"); 
    spacer2_2_2_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2_2_2->addItem( spacer2_2_2_2_2_2_2_2_2_2_2_2 );

    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2 = new QLabel( WStackPage_12, "textLabel2_6_2_2_2_2_2_2_2_2_2_2_2" );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setMinimumSize( QSize( 0, 30 ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setMaximumSize( QSize( 32767, 30 ) );
    QFont textLabel2_6_2_2_2_2_2_2_2_2_2_2_2_font(  textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->font() );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2_font.setPointSize( 14 );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2_font.setBold( TRUE );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setFont( textLabel2_6_2_2_2_2_2_2_2_2_2_2_2_font ); 
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setFrameShape( QLabel::NoFrame );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setFrameShadow( QLabel::Plain );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setLineWidth( 0 );
    layout5_2_2_2_2_2_2_2_2_2_2_2->addWidget( textLabel2_6_2_2_2_2_2_2_2_2_2_2_2 );
    spacer3_2_2_2_2_2_2_2_2_2_2_2 = new QSpacerItem( 137, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5_2_2_2_2_2_2_2_2_2_2_2->addItem( spacer3_2_2_2_2_2_2_2_2_2_2_2 );

    WStackPageLayout_12->addLayout( layout5_2_2_2_2_2_2_2_2_2_2_2, 0, 0 );

    frame16 = new QFrame( WStackPage_12, "frame16" );
    frame16->setFrameShape( QFrame::StyledPanel );
    frame16->setFrameShadow( QFrame::Raised );
    frame16Layout = new QGridLayout( frame16, 1, 1, 11, 6, "frame16Layout"); 

    layout78 = new QVBoxLayout( 0, 0, 6, "layout78"); 

    textLabel1_13 = new QLabel( frame16, "textLabel1_13" );
    layout78->addWidget( textLabel1_13 );

    windowsFont = new QListBox( frame16, "windowsFont" );
    windowsFont->setMaximumSize( QSize( 32767, 32767 ) );
    windowsFont->setFocusPolicy( QListBox::NoFocus );
    windowsFont->setSelectionMode( QListBox::NoSelection );
    layout78->addWidget( windowsFont );

    frame16Layout->addLayout( layout78, 0, 0 );

    layout78_2 = new QVBoxLayout( 0, 0, 6, "layout78_2"); 

    textLabel1_13_2 = new QLabel( frame16, "textLabel1_13_2" );
    layout78_2->addWidget( textLabel1_13_2 );

    visualLocalFont = new QListBox( frame16, "visualLocalFont" );
    layout78_2->addWidget( visualLocalFont );

    frame16Layout->addLayout( layout78_2, 0, 1 );

    mapFontSelection = new QPushButton( frame16, "mapFontSelection" );
    mapFontSelection->setMinimumSize( QSize( 25, 25 ) );
    mapFontSelection->setMaximumSize( QSize( 25, 25 ) );
    mapFontSelection->setAutoDefault( FALSE );
    mapFontSelection->setIconSet( QIconSet( image4 ) );

    frame16Layout->addWidget( mapFontSelection, 0, 2 );

    layout150 = new QHBoxLayout( 0, 0, 6, "layout150"); 

    fontComment = new QTextEdit( frame16, "fontComment" );
    fontComment->setMinimumSize( QSize( 0, 110 ) );
    fontComment->setMaximumSize( QSize( 32767, 110 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Background, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    fontComment->setPalette( pal );
    fontComment->setBackgroundOrigin( QTextEdit::WidgetOrigin );
    fontComment->setFrameShape( QTextEdit::NoFrame );
    fontComment->setFrameShadow( QTextEdit::Plain );
    fontComment->setLineWidth( 0 );
    fontComment->setReadOnly( TRUE );
    layout150->addWidget( fontComment );
    spacer140 = new QSpacerItem( 30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout150->addItem( spacer140 );

    frame16Layout->addMultiCellLayout( layout150, 2, 2, 0, 2 );

    layout73 = new QHBoxLayout( 0, 0, 6, "layout73"); 

    textLabel1_14 = new QLabel( frame16, "textLabel1_14" );
    textLabel1_14->setMinimumSize( QSize( 17, 18 ) );
    textLabel1_14->setMaximumSize( QSize( 17, 18 ) );
    textLabel1_14->setPixmap( image9 );
    layout73->addWidget( textLabel1_14 );

    textLabel2_3 = new QLabel( frame16, "textLabel2_3" );
    layout73->addWidget( textLabel2_3 );
    spacer61 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout73->addItem( spacer61 );

    defaultListButton = new QPushButton( frame16, "defaultListButton" );
    defaultListButton->setMinimumSize( QSize( 100, 0 ) );
    layout73->addWidget( defaultListButton );
    spacer63 = new QSpacerItem( 30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout73->addItem( spacer63 );

    frame16Layout->addMultiCellLayout( layout73, 1, 1, 0, 2 );

    WStackPageLayout_12->addWidget( frame16, 1, 0 );
    widgetList->addWidget( WStackPage_12, 11 );

    configureLayout->addWidget( widgetList, 0, 1 );
    languageChange();
    resize( QSize(651, 495).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( Ok, SIGNAL( clicked() ), this, SLOT( Ok_clicked() ) );
    connect( fileDir, SIGNAL( clicked() ), this, SLOT( fileDir_clicked() ) );
    connect( serviceMessageColor, SIGNAL( clicked() ), this, SLOT( ForeMessageUp_clicked() ) );
    connect( Default, SIGNAL( clicked() ), this, SLOT( Default_clicked() ) );
    connect( globalFontButton, SIGNAL( clicked() ), this, SLOT( globalFontButton_clicked() ) );
    connect( defaultFontButton, SIGNAL( clicked() ), this, SLOT( defaultFontButton_clicked() ) );
    connect( fileOpen1, SIGNAL( clicked() ), this, SLOT( fileOpen1_clicked() ) );
    connect( fileOpen2, SIGNAL( clicked() ), this, SLOT( fileOpen2_clicked() ) );
    connect( fileOpen3, SIGNAL( clicked() ), this, SLOT( fileOpen3_clicked() ) );
    connect( fileOpen4, SIGNAL( clicked() ), this, SLOT( fileOpen4_clicked() ) );
    connect( fileOpen5, SIGNAL( clicked() ), this, SLOT( fileOpen5_clicked() ) );
    connect( playDemo1, SIGNAL( clicked() ), this, SLOT( playDemo1_clicked() ) );
    connect( playDemo2, SIGNAL( clicked() ), this, SLOT( playDemo2_clicked() ) );
    connect( playDemo3, SIGNAL( clicked() ), this, SLOT( playDemo3_clicked() ) );
    connect( playDemo4, SIGNAL( clicked() ), this, SLOT( playDemo4_clicked() ) );
    connect( playDemo5, SIGNAL( clicked() ), this, SLOT( playDemo5_clicked() ) );
    connect( removeSpecial, SIGNAL( clicked() ), this, SLOT( removeSpecial_clicked() ) );
    connect( specialList, SIGNAL( selected(int) ), widgetList, SLOT( raiseWidget(int) ) );
    connect( optionList, SIGNAL( highlighted(int) ), widgetList, SLOT( raiseWidget(int) ) );
    connect( soundSwitch, SIGNAL( clicked() ), this, SLOT( soundSwitch_clicked() ) );
    connect( beepSwitch, SIGNAL( clicked() ), this, SLOT( beepSwitch_clicked() ) );
    connect( proxyAuthSwitch, SIGNAL( toggled(bool) ), proxyUser, SLOT( setEnabled(bool) ) );
    connect( proxyAuthSwitch, SIGNAL( toggled(bool) ), proxyPassword, SLOT( setEnabled(bool) ) );
    connect( proxySwitch, SIGNAL( toggled(bool) ), this, SLOT( proxySwitch_toggled(bool) ) );
    connect( contactSelFont, SIGNAL( clicked() ), this, SLOT( contactSelFont_clicked() ) );
    connect( groupNameForeColor, SIGNAL( clicked() ), this, SLOT( groupNameForeColor_clicked() ) );
    connect( contactForeColor, SIGNAL( clicked() ), this, SLOT( contactForeColor_clicked() ) );
    connect( addSpecial, SIGNAL( clicked() ), this, SLOT( addSpecial_clicked() ) );
    connect( Apply, SIGNAL( clicked() ), this, SLOT( Apply_clicked() ) );
    connect( activateStyle, SIGNAL( toggled(bool) ), styleCombo, SLOT( setEnabled(bool) ) );
    connect( Cancel, SIGNAL( clicked() ), this, SLOT( Cancel_clicked() ) );
    connect( SelFontUp, SIGNAL( clicked() ), this, SLOT( SelFontUp_clicked() ) );
    connect( netfriendColorButton, SIGNAL( clicked() ), this, SLOT( ForeNetFriendUp_clicked() ) );
    connect( myselfColor, SIGNAL( clicked() ), this, SLOT( ForeColorUp_clicked() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
configure::~configure()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void configure::languageChange()
{
    setCaption( ( "OpenC6 - Configurazione" ) );
    Ok->setText( ( "OK" ) );
    QToolTip::add( Ok, ( "Applica le impostazioni correnti e chiude la finestra di configurazione" ) );
    Apply->setText( ( "Applica" ) );
    QToolTip::add( Apply, ( "Applica le impostazioni correnti" ) );
    Cancel->setText( ( "Cancella" ) );
    QToolTip::add( Cancel, ( "Esce senza applicare le impostazioni" ) );
    optionList->clear();
    optionList->insertItem( ( "Generale" ) );
    optionList->insertItem( ( "Connessione" ) );
    optionList->insertItem( ( "Chat" ) );
    optionList->insertItem( ( "Stanze" ) );
    optionList->insertItem( ( "Messaggi automatici" ) );
    optionList->insertItem( ( "Font dell'applicazione" ) );
    optionList->insertItem( ( "Suoni" ) );
    optionList->insertItem( ( "Lista speciale" ) );
    optionList->insertItem( ( "Log" ) );
    optionList->insertItem( ( "Plugin manager" ) );
    optionList->insertItem( ( "Stile" ) );
    optionList->insertItem( ( "Mappa dei font [chat]" ) );
    optionList->setCurrentItem( -1 );
    textLabel2_6->setText( ( " Generale" ) );
    ShowOnline->setText( ( "Mostra solo utenti online" ) );
    QToolTip::add( ShowOnline, ( "Mostra solo gli utenti che sono online" ) );
    dockIcon->setText( ( "Riduci ad icona all'avvio" ) );
    QToolTip::add( dockIcon, ( "Riduce ad icona l'applicazione automaticamente all'avvio [solo se attivo il plugin per il support KDE]" ) );
    textLabel1->setText( ( "Browser predefinito" ) );
    Browser->setText( ( "mozilla" ) );
    QToolTip::add( Browser, ( "Browser predefinito" ) );
    authGroup->setTitle( ( "Autorizzazioni" ) );
    warnAuthButton->setText( ( "Avvisa ad inserimento in lista" ) );
    QToolTip::add( warnAuthButton, ( "Avvisa quando qualcuno ti inserisce in lista" ) );
    askAuthButton->setText( ( "Richiedi autorizzazione ad inserimento il lista" ) );
    QToolTip::add( askAuthButton, ( "Richiede autorizzazione quando qualcuno ti inserisce in lista" ) );
    noAuthButton->setText( ( "Nessuna autorizzazione" ) );
    QToolTip::add( noAuthButton, ( "Tutti possono insertirti in lista " ) );
    messageGroup->setTitle( ( "Messaggi offline" ) );
    reportButton->setText( ( "in segreteria al collegamento successivo" ) );
    emailButton->setText( ( "per e-mail " ) );
    groupBox1->setTitle( ( " Opzioni di connessione " ) );
    textLabel1_7->setText( ( "Stato iniziale all'avvio " ) );
    startStatusSwitch->clear();
    startStatusSwitch->insertItem( ( "Disponibile" ) );
    startStatusSwitch->insertItem( ( "Solo amici" ) );
    startStatusSwitch->insertItem( ( "Occupato" ) );
    startStatusSwitch->insertItem( ( "Assente" ) );
    QToolTip::add( startStatusSwitch, ( "Specifica lo stato iniziale della connesione" ) );
    textLabel1_7_2->setText( ( "Timeout scelta nick (sec)" ) );
    AutoConnect->setText( ( "Connessione automatica all'avvio" ) );
    QToolTip::add( AutoConnect, ( "Effettua la connessione automatica all'avvio del client" ) );
    Reconnect->setText( ( "Riconnetti quando disconnesso" ) );
    QToolTip::add( Reconnect, ( "Effettua una riconnessione automatica nel caso il server disconnetta l'utente o si verifichi un errore sulla connessione di rete" ) );
    ipShow->setText( ( "Rendi visibile l'IP" ) );
    QToolTip::add( ipShow, ( "Rende visibile all'esterno il proprio indirizzo IP" ) );
    textLabel2_6_2->setText( ( "Connessione" ) );
    groupBox2->setTitle( ( " Configurazione server " ) );
    proxySwitch->setText( ( "Proxy" ) );
    QToolTip::add( proxyName, ( "Nome del server " ) );
    textLabel2_4->setText( ( "Porta" ) );
    proxySocksVersion->clear();
    proxySocksVersion->insertItem( ( "Socks4" ) );
    proxySocksVersion->insertItem( ( "Socks5" ) );
    textLabel1_2->setText( ( "Server" ) );
    QToolTip::add( serverName, ( "Nome del server " ) );
    textLabel2->setText( ( "Porta" ) );
    proxyAuthBox->setTitle( ( " Autenticazione Proxy" ) );
    textLabel3_3->setText( ( "Password" ) );
    proxyAuthSwitch->setText( ( "Attiva" ) );
    textLabel2_2->setText( ( "UserId" ) );
    textLabel2_6_2_2->setText( ( "Chat" ) );
    groupBox9->setTitle( QString::null );
    AutoRaise->setText( ( "Auto-Raise chat" ) );
    QToolTip::add( AutoRaise, ( "Alza la finestra di chat in caso di messaggio" ) );
    AutoPopUp->setText( ( "Auto-Popup chat" ) );
    QToolTip::add( AutoPopUp, ( "Apre la finestra di chat in caso di nuovo messaggio" ) );
    timeStamp->setText( ( "Visualizza ora" ) );
    QToolTip::add( timeStamp, ( "Visualizza l'ora corrente dei messaggi nella finestra di chat" ) );
    tabbedChat->setText( ( "Tabbed chat" ) );
    QToolTip::add( tabbedChat, ( "Attiva la gestione dei tab" ) );
    acceptFile->setTitle( ( "Invio/Ricezione File " ) );
    autoAccept->setText( ( "Accetta sempre file" ) );
    QToolTip::add( autoAccept, ( "Accetta in maniera automatica la ricezione dei file" ) );
    textLabel1_10->setText( ( "Directory di ricezione file" ) );
    QToolTip::add( textLabel1_10, ( "Directory di default per la ricezione file" ) );
    QToolTip::add( fileReceivePath, ( "Path di default per la ricezione file" ) );
    fileDir->setText( QString::null );
    textLabel4_3->setText( ( "Porta ricezione file" ) );
    QToolTip::add( startPort, ( "Porta iniziale di ascolto nel caso di ricezione file" ) );
    textLabel2_6_2_2_2->setText( ( "Stanze" ) );
    groupBox10->setTitle( QString::null );
    roomTimeStamp->setText( ( "Visualizza ora" ) );
    QToolTip::add( roomTimeStamp, ( "Visualizza l'ora corrente dei messaggi nella stanza per ogni messaggio" ) );
    autoRoomEnter->setText( ( "Apertura stanze all'avvio" ) );
    QToolTip::add( autoRoomEnter, ( "Abilita all'avvio l'apertura della lista di stanze specificata" ) );
    QToolTip::add( autoRoomList, ( "Immettere una lista di stanze una per riga e separate da un ritorno a capo" ) );
    textLabel2_6_2_2_2_2->setText( ( "Messaggi automatici" ) );
    groupBox11->setTitle( QString::null );
    AutoMsg->setText( ( "Attiva messaggi automatici" ) );
    QToolTip::add( AutoMsg, ( "Attiva il risponditore automatico " ) );
    textLabel3_5->setText( ( "Amico in lista nera" ) );
    QToolTip::add( BlackListEdit, ( "Messaggio automatico nel caso di netfriend in lista nera" ) );
    textLabel4_5->setText( ( "Solo amici" ) );
    QToolTip::add( NetFriendsEdit, ( "Messaggio automatico nel caso di \"solo netfriend\"" ) );
    textLabel5->setText( ( "Occupato" ) );
    QToolTip::add( BusyEdit, ( "Messaggio automatico nel caso di \"occupato\"" ) );
    textLabel1_9->setText( ( "Assente" ) );
    QToolTip::add( AwayEdit, ( "Messaggio automatico nel caso di \"assente\"" ) );
    autoAwaySwitch->setText( ( "Vai in \"Assente\" dopo " ) );
    QToolTip::add( autoAwaySwitch, ( "Imposta automaticamente il client nello stato di \"assente\" dopo il numero di minuti impostato" ) );
    textLabel1_12->setText( ( "minuti" ) );
    backAutoAwaySwitch->setText( ( "Ritorno stato automatico" ) );
    QToolTip::add( backAutoAwaySwitch, ( "Ritorna in maniera automatica allo stato precedente allo stato di assente quando si ritorna al desktop" ) );
    textLabel2_6_2_2_2_2_2->setText( ( "Font" ) );
    groupBox13->setTitle( ( "Applicazione" ) );
    selectFontButton->setText( ( "Manuale" ) );
    QToolTip::add( selectFontButton, ( "Permette la selezione manuale del font usato dall'applicazione. Quando non attivata viene effettuata una rilevazione automatica del font di sistema." ) );
    textLabel1_11->setText( ( "Font:" ) );
    globalFontButton->setText( QString::null );
    QToolTip::add( globalFontButton, ( "Selezione del font" ) );
    defaultFontButton->setText( ( "Default" ) );
    QToolTip::add( defaultFontButton, ( "Seleziona colore e font di default" ) );
    groupBox12->setTitle( ( "Chat" ) );
    Default->setText( ( "Default" ) );
    QToolTip::add( Default, ( "Seleziona colore e font di default" ) );
    groupBox15->setTitle( QString::null );
    textLabel1_8->setText( ( "Font:" ) );
    SelFontUp->setText( QString::null );
    QToolTip::add( SelFontUp, ( "Seleziona il font dei nickname, orario di conversazione e messaggi di servizio" ) );
    textLabel1_4_4->setText( ( "Amico:" ) );
    netfriendColorButton->setText( QString::null );
    QToolTip::add( netfriendColorButton, ( "Seleziona il colore del nickname dell'amico" ) );
    textLabel3_2_5->setText( ( "Me:" ) );
    myselfColor->setText( QString::null );
    QToolTip::add( myselfColor, ( "Seleziona il colore del nostro nickname" ) );
    chatPreview->setText( QString::null );
    MessageUpLabel->setText( ( "Extra:" ) );
    serviceMessagePreview->setText( ( "- Il netfriend pinco.p è appena entrato in chat -" ) );
    serviceMessageColor->setText( QString::null );
    QToolTip::add( serviceMessageColor, ( "Selezione il colore del testo di messaggi di servizio" ) );
    groupBox11_2->setTitle( ( "Lista contatti" ) );
    contactFontSwitch->setText( ( "Manuale" ) );
    QToolTip::add( contactFontSwitch, ( "Permette la selezione manuale del font. Quando non attivata viene effettuata una rilevazione automatica del font di default." ) );
    textLabel1_8_2->setText( ( "Font:" ) );
    contactSelFont->setText( QString::null );
    MessageUpLabel_2->setText( ( "Colore contatto:" ) );
    groupNameForeColor->setText( QString::null );
    MessageUpLabel_3->setText( ( "Colore nome gruppo:" ) );
    contactForeColor->setText( QString::null );
    defaultContact->setText( ( "Default" ) );
    QToolTip::add( defaultContact, ( "Seleziona colore e font di default" ) );
    textLabel2_6_2_2_2_2_2_2->setText( ( "Suoni" ) );
    beepSwitch->setText( ( "Beep messaggio ricevuto" ) );
    soundOnceSwitch->setText( ( "Solo al primo messaggio" ) );
    QToolTip::add( soundOnceSwitch, ( "Emette il suono o il beep solo al primo messaggio" ) );
    soundSwitch->setText( ( "Attivazione suoni" ) );
    QToolTip::add( soundSwitch, ( "Attiva i suoni" ) );
    textLabel1_5->setText( ( "Comando player" ) );
    QToolTip::add( playCommand, ( "Player file audio " ) );
    soundGroup->setTitle( ( "Notifiche" ) );
    inMessageSwitch->setText( ( "Messaggio ricevuto" ) );
    QToolTip::add( inMessageSwitch, ( "Messagio in ricezione" ) );
    fileOpen1->setText( QString::null );
    playDemo1->setText( QString::null );
    QToolTip::add( playDemo1, ( "Preascolto del wav" ) );
    outMessageSwitch->setText( ( "Messaggio mandato" ) );
    QToolTip::add( outMessageSwitch, ( "Messaggio in uscita" ) );
    fileOpen2->setText( QString::null );
    playDemo2->setText( QString::null );
    QToolTip::add( playDemo2, ( "Preascolto del wav" ) );
    onlineMessageSwitch->setText( ( "Amico online" ) );
    QToolTip::add( onlineMessageSwitch, ( "Amico online" ) );
    fileOpen3->setText( QString::null );
    playDemo3->setText( QString::null );
    QToolTip::add( playDemo3, ( "Preascolto del wav" ) );
    offlineMessageSwitch->setText( ( "Amico offline" ) );
    QToolTip::add( offlineMessageSwitch, ( "Amico offline" ) );
    fileOpen4->setText( QString::null );
    playDemo4->setText( QString::null );
    QToolTip::add( playDemo4, ( "Preascolto del wav" ) );
    specialFriendSwitch->setText( ( "Netfriend speciale" ) );
    QToolTip::add( specialFriendSwitch, ( "Netfriend speciale online" ) );
    fileOpen5->setText( QString::null );
    playDemo5->setText( QString::null );
    QToolTip::add( playDemo5, ( "Preascolto del wav" ) );
    textLabel2_6_2_2_2_2_2_2_2->setText( ( "Lista speciale" ) );
    textLabel1_4->setText( ( "Lista speciale" ) );
    QToolTip::add( specialList, ( "Player file audio " ) );
    textLabel1_6->setText( ( "Amico speciale" ) );
    removeSpecial->setText( ( "Elimina" ) );
    QToolTip::add( removeSpecial, ( "Elimina il nick di un netfriend speciale" ) );
    addSpecial->setText( ( "Aggiungi" ) );
    QToolTip::add( addSpecial, ( "Aggiunge il nick di un netfriend speciale" ) );
    specialNotifySwitch->setText( ( "Notifica in chat" ) );
    QToolTip::add( specialNotifySwitch, ( "Notifica nella finestra corrente di chat la connessione del netfriend speciale" ) );
    textLabel2_6_2_2_2_2_2_2_2_2->setText( ( "Log" ) );
    LogProto->setText( ( "Log pacchetti server-client" ) );
    QToolTip::add( LogProto, ( "Attiva il log della comunicazione client sever" ) );
    Log->setText( ( "Log conversazioni private" ) );
    QToolTip::add( Log, ( "Attiva il log di tutte le conversazioni" ) );
    LogRoom->setText( ( "Log conversazioni stanze" ) );
    QToolTip::add( LogRoom, ( "Attiva il log di tutte le conversazioni in stanza" ) );
    SysLog->setText( ( "Log di sistema" ) );
    QToolTip::add( SysLog, ( "Attiva il log di sistema" ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2->setText( ( "Plugin Manager" ) );
    groupBox13_2->setTitle( ( "Caricati" ) );
    pluginsLoadedList->header()->setLabel( 0, ( "File" ) );
    pluginsLoadedList->header()->setLabel( 1, ( "Nome" ) );
    pluginsLoadedList->header()->setLabel( 2, ( "Descrizione" ) );
    pluginsLoadedList->header()->setLabel( 3, ( "KDE" ) );
    pluginsLoadedList->header()->setLabel( 4, ( "Attivo" ) );
    pluginUnload->setText( ( "Elimina" ) );
    groupBox12_2->setTitle( ( "Disponibili " ) );
    pluginsAvailableList->header()->setLabel( 0, ( "Column 1" ) );
    pluginLoad->setText( ( "Carica " ) );
    textLabel1_3->setText( ( "* Riavviare per rendere effettive le modifiche" ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2->setText( ( "Stile" ) );
    groupBox27->setTitle( ( "Stile applicazione" ) );
    activateStyle->setText( ( "Attiva" ) );
    textLabel1_2_2->setText( ( "Stile" ) );
    textLabel2_6_2_2_2_2_2_2_2_2_2_2_2->setText( ( "Mappa dei font  [chat]" ) );
    textLabel1_13->setText( ( "Font utente remoto" ) );
    windowsFont->clear();
    windowsFont->insertItem( ( "Arial" ) );
    windowsFont->insertItem( ( "Arial Black" ) );
    windowsFont->insertItem( ( "Comic Sans MS" ) );
    windowsFont->insertItem( ( "Courier New" ) );
    windowsFont->insertItem( ( "Georgia" ) );
    windowsFont->insertItem( ( "Impact" ) );
    windowsFont->insertItem( ( "Times New Roman" ) );
    windowsFont->insertItem( ( "Trebuchet MS" ) );
    windowsFont->insertItem( ( "Verdana" ) );
    windowsFont->insertItem( ( "Webdings" ) );
    textLabel1_13_2->setText( ( "Font locale" ) );
    mapFontSelection->setText( QString::null );
    QToolTip::add( mapFontSelection, ( "Seleziona il font" ) );
    fontComment->setText( QString::null );
    textLabel1_14->setText( QString::null );
    textLabel2_3->setText( ( "probabile assenza del font" ) );
    defaultListButton->setText( ( "Default" ) );
    QToolTip::add( defaultListButton, ( "Ripristina le impostazioni di default" ) );
}

#include "configure.moc"
